(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 11.2' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[     89700,       1699]
NotebookOptionsPosition[     88998,       1675]
NotebookOutlinePosition[     89411,       1692]
CellTagsIndexPosition[     89368,       1689]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{"Importing", " ", "Data"}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"path", "=", 
     RowBox[{"SystemDialogInput", "[", "\"\<FileOpen\>\"", "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"dataimport", "=", 
     RowBox[{"Delete", "[", 
      RowBox[{
       RowBox[{"Import", "[", 
        RowBox[{"path", ",", "\"\<Data\>\""}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", "1", "}"}], ",", 
         RowBox[{"{", "2", "}"}]}], "}"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ForwSweep", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"dataimport", "[", 
          RowBox[{"[", 
           RowBox[{"i", ",", "1"}], "]"}], "]"}], ",", 
         RowBox[{"dataimport", "[", 
          RowBox[{"[", 
           RowBox[{"i", ",", "2"}], "]"}], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "1", ",", 
         RowBox[{"Length", "[", "dataimport", "]"}]}], "}"}]}], "]"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"BackSweep", " ", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"dataimport", "[", 
          RowBox[{"[", 
           RowBox[{"i", ",", "3"}], "]"}], "]"}], ",", 
         RowBox[{"dataimport", "[", 
          RowBox[{"[", 
           RowBox[{"i", ",", "4"}], "]"}], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "1", ",", 
         RowBox[{"Length", "[", "dataimport", "]"}]}], "}"}]}], "]"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"{", 
     RowBox[{"ForwSweep", ",", "BackSweep"}], "}"}], "]"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.7302929960525923`*^9, 3.7302930245023704`*^9}, {
  3.7302934121632376`*^9, 3.7302934174688635`*^9}, {3.732687306845978*^9, 
  3.73268733452439*^9}},
 ExpressionUUID -> "f2ae5c15-7673-4d7a-a962-c844bd42f7fd"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
   "Subtracting", " ", "dead", " ", "layers", " ", "using", " ", "VSM", " ", 
    "magnetic", " ", "moment", " ", "data"}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Options", "[", "RealThicknesses", "]"}], "=", 
     RowBox[{"{", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Mstheor", "\[Rule]", "800000"}], 
       RowBox[{"(*", 
        RowBox[{"A", "/", "m"}], "*)"}], " ", 
       RowBox[{"(*", " ", 
        RowBox[{
        "Bulk", " ", "saturation", " ", "magnetization", " ", "of", " ", 
         "Ni81Fe19"}], "*)"}], ",", "\[IndentingNewLine]", 
       RowBox[{"MMsat", "\[Rule]", 
        RowBox[{"1.90", "*", 
         SuperscriptBox["10", 
          RowBox[{"-", "8"}]]}]}], 
       RowBox[{"(*", 
        RowBox[{"A", "*", 
         SuperscriptBox["m", "2"]}], "*)"}], " ", 
       RowBox[{"(*", 
        RowBox[{
        "Saturated", " ", "total", " ", "magnetic", " ", "moment", " ", 
         "from", " ", "VSM"}], "*)"}], ",", "\[IndentingNewLine]", 
       RowBox[{"MMdiff", " ", "\[Rule]", 
        RowBox[{"0.342", "*", 
         SuperscriptBox["10", 
          RowBox[{"-", "8"}]]}]}], 
       RowBox[{"(*", 
        RowBox[{"A", "*", 
         SuperscriptBox["m", "2"]}], "*)"}], " ", 
       RowBox[{"(*", 
        RowBox[{
        "Antiparallel", " ", "state", " ", "total", " ", "magnetic", " ", 
         "moment", " ", "from", " ", "VSM"}], "*)"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Thickness1", "\[Rule]", 
        RowBox[{"3", "*", 
         SuperscriptBox["10", 
          RowBox[{"-", "9"}]]}]}], " ", 
       RowBox[{"(*", "m", "*)"}], 
       RowBox[{"(*", 
        RowBox[{
        "Expected", " ", "Thickness", " ", "of", " ", "the", " ", "1", "st", 
         " ", "layer"}], "*)"}], ",", "\[IndentingNewLine]", 
       RowBox[{"Thickness2", "\[Rule]", 
        RowBox[{"3", "*", 
         SuperscriptBox["10", 
          RowBox[{"-", "9"}]]}]}], "  ", 
       RowBox[{"(*", "m", "*)"}], 
       RowBox[{"(*", 
        RowBox[{
        "Expected", " ", "Thickness", " ", "of", " ", "the", " ", "2", "nd", 
         " ", "layer"}], "*)"}], ",", "\[IndentingNewLine]", 
       RowBox[{"area", "\[Rule]", " ", 
        RowBox[{"16", "*", 
         SuperscriptBox["10", 
          RowBox[{"-", "6"}]]}]}]}], 
      RowBox[{"(*", 
       SuperscriptBox["m", "2"], "*)"}], "\[IndentingNewLine]", "}"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"RealThicknesses", "[", 
     RowBox[{"OptionsPattern", "[", "]"}], "]"}], ":=", 
    RowBox[{"Module", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"t1", "=", 
         RowBox[{"OptionValue", "[", "Thickness1", "]"}]}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"t2", "=", 
         RowBox[{"OptionValue", "[", "Thickness2", "]"}]}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"Msat", "=", 
         RowBox[{"OptionValue", "[", "Mstheor", "]"}]}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"MMsat", "=", 
         RowBox[{"OptionValue", "[", "MMsat", "]"}]}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"MMdiff", "=", 
         RowBox[{"OptionValue", "[", "MMdiff", "]"}]}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"S", "=", 
         RowBox[{"OptionValue", "[", "area", "]"}]}], ",", 
        "\[IndentingNewLine]", "\[Gamma]", ",", "M1", ",", "M2", ",", "t1eff",
         ",", "t2eff", ",", "resDL", ",", "res", ",", "\[Gamma]eff", ",", 
        "DeadLayersTh", ",", "DLTh1", ",", "DLTh2"}], "\[IndentingNewLine]", 
       "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"DeadLayersTh", "=", 
        RowBox[{"Flatten", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"DLTh1", ",", "DLTh2"}], "}"}], "/.", 
          RowBox[{"Solve", "[", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"{", "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{
               RowBox[{"DLTh1", "+", "DLTh2"}], "\[Equal]", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"t1", "+", "t2"}], ")"}], "-", " ", 
                FractionBox["MMsat", 
                 RowBox[{"S", "*", "Msat"}]]}]}], " ", ",", " ", 
              "\[IndentingNewLine]", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"t1", "-", "DLTh1"}], ")"}], "-", 
                RowBox[{"(", " ", 
                 RowBox[{"t2", "-", "DLTh2"}], ")"}]}], "\[Equal]", 
               FractionBox["MMdiff", 
                RowBox[{"S", "*", "Msat"}]]}]}], "\[IndentingNewLine]", "}"}],
             ",", 
            RowBox[{"{", 
             RowBox[{"DLTh1", ",", "DLTh2"}], "}"}]}], "\[IndentingNewLine]", 
           "]"}]}], "\[IndentingNewLine]", "]"}]}], ";", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"t1eff", "=", 
        RowBox[{"t1", "-", 
         RowBox[{"DeadLayersTh", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"t2eff", "=", 
        RowBox[{"t2", "-", 
         RowBox[{"DeadLayersTh", "[", 
          RowBox[{"[", "2", "]"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"res", "=", 
        RowBox[{"{", 
         RowBox[{"t1eff", ",", "t2eff"}], "}"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"(*", 
        RowBox[{
         RowBox[{
          RowBox[{"{", "res", "}"}], "=", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"M1", ",", "M2"}], "}"}], "/.", 
           RowBox[{"Solve", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{
                RowBox[{"M1", "+", 
                 RowBox[{"M2", "*", "\[Gamma]"}]}], "\[Equal]", 
                RowBox[{"Mpar", "*", 
                 RowBox[{"(", 
                  RowBox[{"1", "+", "\[Gamma]"}], ")"}]}]}], ",", 
               RowBox[{
                RowBox[{"M1", "-", 
                 RowBox[{"M2", "*", "\[Gamma]"}]}], "\[Equal]", 
                RowBox[{"Mapar", "*", 
                 RowBox[{"(", 
                  RowBox[{"1", "+", "\[Gamma]"}], ")"}]}]}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"M1", ",", "M2"}], "}"}]}], "]"}]}]}], ";"}], "*)"}], 
       "\[IndentingNewLine]", 
       RowBox[{"(*", 
        RowBox[{"Return", "[", "res", "]"}], "*)"}], "\[IndentingNewLine]", 
       RowBox[{"Return", "[", "res", "]"}]}]}], "\[IndentingNewLine]", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", "]"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{"pt1", "=", 
    RowBox[{
     RowBox[{"RealThicknesses", "[", "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}]}], "\[IndentingNewLine]", 
   RowBox[{"pt2", "=", 
    RowBox[{
     RowBox[{"RealThicknesses", "[", "]"}], "[", 
     RowBox[{"[", "2", "]"}], "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.7293209859114203`*^9, 3.729321013309265*^9}, {
   3.729321047967413*^9, 3.7293210960302*^9}, {3.7293211276973963`*^9, 
   3.7293211660315514`*^9}, {3.7293212895560007`*^9, 
   3.7293216484348974`*^9}, {3.7293217447193956`*^9, 
   3.7293217808785343`*^9}, {3.7293219474634886`*^9, 
   3.7293221528441153`*^9}, {3.7293243491746936`*^9, 3.72932434957275*^9}, 
   3.7293246925113244`*^9, {3.7293247229081416`*^9, 3.7293247797431316`*^9}, {
   3.7293249643422766`*^9, 3.729325037729933*^9}, {3.729325076184202*^9, 
   3.729325129658348*^9}, {3.729326581739665*^9, 3.7293268141858997`*^9}, {
   3.729326895911561*^9, 3.7293273532816715`*^9}, {3.729327487176317*^9, 
   3.729327618811303*^9}, {3.7293281621279106`*^9, 3.7293281654648046`*^9}, {
   3.729330882469883*^9, 3.72933109255126*^9}, {3.7293311483325357`*^9, 
   3.7293312024273615`*^9}, {3.729331271453258*^9, 3.7293313372451725`*^9}, {
   3.729331370192772*^9, 3.729331384455597*^9}, {3.729331417739093*^9, 
   3.7293314193343267`*^9}, {3.7293315004452653`*^9, 3.7293316089055634`*^9}, 
   3.7293316521826267`*^9, {3.7293318802218924`*^9, 3.7293319241536827`*^9}, {
   3.7293319625443926`*^9, 3.729332054402695*^9}, {3.7293320975790987`*^9, 
   3.729332123049988*^9}, {3.7293321921953287`*^9, 3.7293322187626853`*^9}, {
   3.729332287925046*^9, 3.729332336235719*^9}, {3.7293323668891516`*^9, 
   3.7293323904767523`*^9}, {3.729332447177934*^9, 3.7293324967349305`*^9}, {
   3.7293325783477454`*^9, 3.7293326008205357`*^9}, {3.729332638128536*^9, 
   3.729332661866377*^9}, {3.72933276260126*^9, 3.7293327683279486`*^9}, {
   3.7293329483055377`*^9, 3.729333004247608*^9}, {3.7293330344150677`*^9, 
   3.7293330700371614`*^9}, 3.729333185059953*^9, {3.729333451115859*^9, 
   3.7293334749551277`*^9}, {3.729333564330291*^9, 3.7293336615968866`*^9}, {
   3.7293337209761114`*^9, 3.7293337216579237`*^9}, 3.7293419118616333`*^9, {
   3.7293507115667377`*^9, 3.7293507765708933`*^9}, {3.729350875962558*^9, 
   3.7293509409236064`*^9}, {3.7293510491683655`*^9, 
   3.7293511346814966`*^9}, {3.729351171158905*^9, 3.7293512489359035`*^9}, {
   3.729351290503873*^9, 3.7293513712478094`*^9}, {3.729351424609253*^9, 
   3.729351425918763*^9}, {3.729351466298067*^9, 3.72935146800809*^9}, {
   3.7293515617945414`*^9, 3.729351605806424*^9}, {3.729352072604698*^9, 
   3.7293520786773405`*^9}, {3.729352118081852*^9, 3.729352137274881*^9}, {
   3.7293522005290585`*^9, 3.729352252587469*^9}, {3.7293530857458773`*^9, 
   3.7293531158920283`*^9}, {3.7293531737017307`*^9, 
   3.7293531928576884`*^9}, {3.729353244419752*^9, 3.729353339621891*^9}, {
   3.7293536465946693`*^9, 3.7293536468102427`*^9}, {3.7293536872096553`*^9, 
   3.7293538639465556`*^9}, {3.729353925575411*^9, 3.7293539739199467`*^9}, {
   3.729354220903617*^9, 3.7293542241181636`*^9}, {3.729354306509221*^9, 
   3.729354310353469*^9}, {3.729354352586732*^9, 3.729354485960374*^9}, {
   3.7293579356731825`*^9, 3.7293579478555994`*^9}, {3.729357992217521*^9, 
   3.7293580132905474`*^9}, {3.729358105641667*^9, 3.7293581073973274`*^9}, {
   3.729358148397317*^9, 3.72935816401484*^9}, {3.7293582137150087`*^9, 
   3.729358374845764*^9}, {3.7293586080317197`*^9, 3.729358660268605*^9}, {
   3.7293587079714622`*^9, 3.7293587620472097`*^9}, {3.7293588027514324`*^9, 
   3.729358814954879*^9}, {3.729358860772696*^9, 3.729359041333*^9}, {
   3.729359153420933*^9, 3.729359174395699*^9}, {3.7293593201874647`*^9, 
   3.7293593529706273`*^9}, {3.729359965365877*^9, 3.729359970665968*^9}, 
   3.7293600326597953`*^9, {3.7293602628437986`*^9, 3.7293602637261443`*^9}, {
   3.7293603007034893`*^9, 3.7293603115051775`*^9}, {3.7293606567319613`*^9, 
   3.729360680663261*^9}, {3.7293639618930173`*^9, 3.7293639742679195`*^9}, {
   3.7293641637136364`*^9, 3.729364166464951*^9}, 3.7293641973370047`*^9, 
   3.7293646439061956`*^9, {3.729364812956624*^9, 3.729364830578477*^9}, {
   3.7293649013967657`*^9, 3.7293649787975826`*^9}, {3.7293650331951857`*^9, 
   3.729365119449515*^9}, {3.7293651695727797`*^9, 3.7293651716593285`*^9}, {
   3.7293652719640136`*^9, 3.7293652976435394`*^9}, {3.7293655166147337`*^9, 
   3.7293655560183043`*^9}, {3.729923588479156*^9, 3.7299235956983495`*^9}, {
   3.7299238048694844`*^9, 3.729923805075031*^9}, {3.729923841572713*^9, 
   3.7299238435920887`*^9}, {3.7299240292317743`*^9, 3.729924099387301*^9}, {
   3.7299244524351788`*^9, 3.7299244645734797`*^9}, {3.7299244946253524`*^9, 
   3.729924518028507*^9}, {3.729925007108632*^9, 3.729925022733162*^9}, {
   3.7299250540975513`*^9, 3.7299251260578775`*^9}, {3.7299291619851027`*^9, 
   3.7299292621484118`*^9}, {3.729929501139019*^9, 3.7299295271020317`*^9}, {
   3.7299295843191586`*^9, 3.7299296428026514`*^9}, {3.7299296728184566`*^9, 
   3.7299297549909325`*^9}, {3.729929817706707*^9, 3.729929823860068*^9}, {
   3.7299299059863925`*^9, 3.7299299517631016`*^9}, {3.729930063242821*^9, 
   3.7299301122882223`*^9}, {3.7299302117316165`*^9, 
   3.7299302251342444`*^9}, {3.729930276554825*^9, 3.7299302793893585`*^9}, {
   3.7299303393126836`*^9, 3.7299304010809183`*^9}, {3.7299304346531496`*^9, 
   3.7299304372941723`*^9}, {3.729930558997752*^9, 3.7299305604907484`*^9}, {
   3.72993078188037*^9, 3.72993083588192*^9}, {3.7299308735230246`*^9, 
   3.729930948606628*^9}, {3.7299310606595497`*^9, 3.729931124386985*^9}, 
   3.729931166585207*^9, {3.7299312174111843`*^9, 3.7299312188710938`*^9}, {
   3.729931257327338*^9, 3.729931280970199*^9}, {3.729931336616149*^9, 
   3.72993135607987*^9}, {3.729931456304343*^9, 3.7299314644620323`*^9}, {
   3.7299317676982636`*^9, 3.729931768981676*^9}, {3.7299320007041225`*^9, 
   3.72993204698818*^9}, {3.7299324354392204`*^9, 3.7299326447767973`*^9}, {
   3.7299328222494*^9, 3.7299328780568085`*^9}, 3.7299332729949517`*^9, {
   3.7299333836202793`*^9, 3.7299335786277566`*^9}, {3.7299336713532915`*^9, 
   3.729933736259862*^9}, {3.7299338019909067`*^9, 3.7299338037726727`*^9}, {
   3.7299338345314493`*^9, 3.7299338519367304`*^9}, {3.7299339107124977`*^9, 
   3.7299339129725366`*^9}, 3.729933958277989*^9, {3.7299340209506197`*^9, 
   3.729934110471607*^9}, {3.7299342018706408`*^9, 3.729934292371234*^9}, {
   3.7299344369339104`*^9, 3.72993445161191*^9}, {3.729934506085743*^9, 
   3.7299345473143597`*^9}, {3.729934612930845*^9, 3.729934636540591*^9}, {
   3.729934744539734*^9, 3.7299347859598627`*^9}, {3.729934830936472*^9, 
   3.7299348986184254`*^9}, {3.7299349386478233`*^9, 
   3.7299349847895317`*^9}, {3.7299351372789636`*^9, 3.729935144155218*^9}, {
   3.729935193157532*^9, 3.7299352054862947`*^9}, {3.7299352499304757`*^9, 
   3.7299353037555833`*^9}, {3.7299353629549522`*^9, 3.729935365300214*^9}, {
   3.7299353991020594`*^9, 3.7299354022634935`*^9}, {3.729935443316032*^9, 
   3.729935476498228*^9}, {3.7299355471921864`*^9, 3.729935556914034*^9}, {
   3.7299355882212987`*^9, 3.7299358301339917`*^9}, 3.7299358925950317`*^9, 
   3.7299359302989564`*^9, {3.7299359758721514`*^9, 3.7299360781580772`*^9}, {
   3.729936128240234*^9, 3.729936135345153*^9}, {3.7299363023427963`*^9, 
   3.7299363424233675`*^9}, 3.7299364230186443`*^9, {3.729936487779856*^9, 
   3.729936488580986*^9}, {3.7299365441657443`*^9, 3.729936547296067*^9}, {
   3.7299366435388002`*^9, 3.729936667999864*^9}, 3.7299371077460127`*^9, 
   3.729937141126766*^9, 3.7299371857082963`*^9, {3.729937894925065*^9, 
   3.729937922837278*^9}, 3.729937953109764*^9, {3.729938007823205*^9, 
   3.729938020829815*^9}, {3.7299380526133184`*^9, 3.7299380598916435`*^9}, 
   3.7299380993405285`*^9, 3.7299384054309464`*^9, 3.7299384740252943`*^9, 
   3.72993866773155*^9, {3.729938739906446*^9, 3.7299387429545507`*^9}, {
   3.7299409603784013`*^9, 3.7299409760289817`*^9}, {3.729941228027403*^9, 
   3.7299413137102127`*^9}, {3.7299414341083474`*^9, 3.729941453346472*^9}, 
   3.7299416523877325`*^9, {3.7299417521188946`*^9, 3.7299417918214264`*^9}, {
   3.7299420076255226`*^9, 3.7299420121966825`*^9}, {3.7299420545071883`*^9, 
   3.7299420802445984`*^9}, {3.7299421591503887`*^9, 3.729942162902365*^9}, {
   3.7299421990946174`*^9, 3.729942232304889*^9}, {3.7299423096806135`*^9, 
   3.7299423132450895`*^9}, {3.729942390933671*^9, 3.7299423911512227`*^9}, 
   3.7299424781185603`*^9, 3.72994312942468*^9, {3.729943210519328*^9, 
   3.7299432286789722`*^9}, {3.729943385104375*^9, 3.7299433868379517`*^9}, {
   3.7299435975157857`*^9, 3.729943603282117*^9}, {3.729943677955455*^9, 
   3.7299436985101385`*^9}, {3.729952689741935*^9, 3.729952702087788*^9}, {
   3.729958785854088*^9, 3.729958786992691*^9}, {3.729958870751807*^9, 
   3.7299588971660233`*^9}, {3.7299590952193575`*^9, 3.729959100657831*^9}, 
   3.729961469386286*^9, {3.7299621333845654`*^9, 3.7299621335736856`*^9}, 
   3.729962248418306*^9, {3.729965639271676*^9, 3.729965642211252*^9}, {
   3.729966114433053*^9, 3.7299661169061832`*^9}, {3.7299661641750884`*^9, 
   3.7299663875442944`*^9}, {3.729966482212372*^9, 3.7299665384445157`*^9}, {
   3.7299678131014667`*^9, 3.729967863517296*^9}, {3.7299693919393897`*^9, 
   3.7299693931444445`*^9}, {3.729975085170754*^9, 3.7299750868250566`*^9}, {
   3.7299753088811207`*^9, 3.729975344548808*^9}, 3.7300938030003505`*^9, {
   3.7301013785351295`*^9, 3.7301013796019692`*^9}, {3.730101523169158*^9, 
   3.730101525498314*^9}, 3.730104062455353*^9, {3.730105113838559*^9, 
   3.730105114324853*^9}, {3.7301051754689803`*^9, 3.730105196677151*^9}, {
   3.7301062262167144`*^9, 3.7301062599199452`*^9}, {3.7301063209948473`*^9, 
   3.730106371318656*^9}, {3.730106434535358*^9, 3.7301064381098824`*^9}, {
   3.7301067829552746`*^9, 3.7301068007024603`*^9}, {3.730106994580603*^9, 
   3.730107077756506*^9}, {3.730107141193515*^9, 3.7301072227268376`*^9}, {
   3.7301073530037556`*^9, 3.7301074202377777`*^9}, 3.7301074657447023`*^9, {
   3.730107499274325*^9, 3.730107499858901*^9}, {3.730107829664833*^9, 
   3.7301078821831026`*^9}, {3.73010791235303*^9, 3.730107937741277*^9}, {
   3.7301080078011775`*^9, 3.7301080622683*^9}, {3.730108184577509*^9, 
   3.7301082463224072`*^9}, {3.7301084105572176`*^9, 3.730108411256076*^9}, {
   3.7301084828828897`*^9, 3.7301084835667076`*^9}, 3.7301085573166485`*^9, {
   3.730109051899516*^9, 3.730109075684436*^9}, {3.7301100257263203`*^9, 
   3.7301100288606825`*^9}, {3.730110151811551*^9, 3.730110152113353*^9}, {
   3.730110329791643*^9, 3.730110336029228*^9}, {3.7301104084427834`*^9, 
   3.7301104100159674`*^9}, {3.7301105074567113`*^9, 3.730110515813959*^9}, 
   3.730110611499335*^9, {3.730110716288945*^9, 3.7301107166649733`*^9}, 
   3.7301107843619347`*^9, 3.730111577292194*^9, {3.7301116662617426`*^9, 
   3.73011167249331*^9}, {3.730112281886674*^9, 3.730112285427087*^9}, {
   3.730112818460292*^9, 3.7301128188954773`*^9}, 3.7301128568684106`*^9, {
   3.7301129281487455`*^9, 3.7301129372449512`*^9}, {3.730112980178086*^9, 
   3.730113009903139*^9}, {3.7301130539702744`*^9, 3.730113054823574*^9}, {
   3.7301143372283964`*^9, 3.7301143701078153`*^9}, {3.730114437829871*^9, 
   3.7301144409331217`*^9}, {3.730121542600752*^9, 3.730121552899104*^9}, {
   3.7301216387564545`*^9, 3.7301216391183844`*^9}, {3.730121712767753*^9, 
   3.730121712911296*^9}, {3.7301217756195126`*^9, 3.730121777725931*^9}, {
   3.730121832519147*^9, 3.730121832689607*^9}, {3.730121885780733*^9, 
   3.7301218988183966`*^9}, {3.730121988056665*^9, 3.7301219882541904`*^9}, {
   3.7301220931272497`*^9, 3.7301220964009857`*^9}, {3.730122198683993*^9, 
   3.7301222037975893`*^9}, {3.730180721243804*^9, 3.7301807423338137`*^9}, {
   3.7301809916481457`*^9, 3.7301810080909195`*^9}, {3.7301811510081263`*^9, 
   3.7301811998640375`*^9}, {3.7301812377681155`*^9, 
   3.7301813079413424`*^9}, {3.730181379931585*^9, 3.730181383253393*^9}, {
   3.7301814134485016`*^9, 3.7301814218738976`*^9}, 3.730184120338315*^9, {
   3.730184187074767*^9, 3.7301843235583096`*^9}, {3.7301843938601007`*^9, 
   3.7301844305563107`*^9}, {3.7301844842871137`*^9, 
   3.7301845562016664`*^9}, {3.7301845964621315`*^9, 
   3.7301846754374733`*^9}, {3.7302579438490477`*^9, 3.730257946048129*^9}, {
   3.7302580230988135`*^9, 3.7302580329948297`*^9}, {3.730266881178776*^9, 
   3.730266885042816*^9}, {3.7302826268020134`*^9, 3.730282651664918*^9}, {
   3.7302929604982452`*^9, 3.7302929701900053`*^9}, {3.7303895006165266`*^9, 
   3.7303895402401075`*^9}, {3.730436493929474*^9, 3.7304365102361016`*^9}, {
   3.7304537218331194`*^9, 3.730453758655396*^9}, {3.730454060562368*^9, 
   3.7304540663405905`*^9}, {3.7304541900291843`*^9, 3.730454203813691*^9}, {
   3.7305300571440735`*^9, 3.730530058886044*^9}, {3.730613748339453*^9, 
   3.7306137484514923`*^9}, {3.7306273238327246`*^9, 
   3.7306273354157686`*^9}, {3.730627455589964*^9, 3.7306274559063053`*^9}, {
   3.73062756559151*^9, 3.73062756716234*^9}, 3.730627916600381*^9, {
   3.730642892172493*^9, 3.7306429283496037`*^9}, {3.730713400708245*^9, 
   3.73071344590681*^9}, {3.730782792107009*^9, 3.7307828152294083`*^9}, {
   3.7307828497429914`*^9, 3.7307828558661165`*^9}, {3.730783141038316*^9, 
   3.7307831631684113`*^9}, {3.730783272236513*^9, 3.7307832849644117`*^9}, {
   3.730783373408198*^9, 3.730783400926137*^9}, {3.730827415957739*^9, 
   3.7308274221023054`*^9}, {3.730827478718444*^9, 3.730827482327099*^9}, 
   3.730827665499463*^9, {3.7308951592655087`*^9, 3.7308951913327374`*^9}, {
   3.7308952467771506`*^9, 3.730895267146307*^9}, {3.730896533042426*^9, 
   3.730896553819908*^9}, {3.731170484545334*^9, 3.731170524545828*^9}, 
   3.7311712392600646`*^9, {3.731171291399184*^9, 3.731171318345059*^9}, {
   3.731171458204365*^9, 3.731171514103076*^9}, {3.7326873561913366`*^9, 
   3.7326874370567923`*^9}, {3.732687641360693*^9, 3.7326876587115717`*^9}, 
   3.7327250798682137`*^9, {3.732725273864786*^9, 3.7327252845161257`*^9}, {
   3.732725350606716*^9, 
   3.7327253570598288`*^9}},ExpressionUUID->"95940a2e-f38f-461b-81c7-\
a8ec9eef38e8"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{
     RowBox[{"This", " ", "magnetizatons", " ", 
      RowBox[{"(", 
       RowBox[{"SaturationValue", ",", "CoupledValue"}], " ", ")"}], " ", 
      "calculated", " ", "as", " ", "magnetic", " ", "moment", " ", "divided",
       " ", "by", " ", "expected", " ", "volume", " ", 
      RowBox[{"(", 
       RowBox[{"16", " ", 
        RowBox[{"mm", "^", "2"}], " ", "*", " ", 
        RowBox[{
         RowBox[{"3", "/", "6"}], "/", "9"}]}], ")"}], " ", "and", " ", 
      "then", "\[IndentingNewLine]", "\[IndentingNewLine]", "corresponding", 
      " ", "values", " ", "determined", " ", "in", " ", "a", " ", "coupled", 
      " ", "and", "  ", "saturated", " ", 
      RowBox[{"state", ".", " ", "So"}], " ", "it", " ", "is", " ", 
      "basically", " ", "normalized", " ", "by", " ", "thickness", " ", "and",
       " ", "area", " ", "magnetic", " ", 
      RowBox[{
      "moment", ".", "\[IndentingNewLine]", "\[IndentingNewLine]", "I"}], " ",
       "did", " ", "it", " ", "in", " ", "this", " ", "way", " ", "because", 
      " ", "this", " ", "is", " ", "the", " ", "only", " ", "way", " ", "one",
       " ", "can", " ", "get", " ", "non"}], "-", 
     RowBox[{
     "zero", " ", "net", " ", "magnetization", " ", "in", " ", "0", " ", 
      "field", " ", "in", " ", "coupled", " ", 
      RowBox[{"state", ".", " ", "I"}], " ", "was", " ", "fitting", " ", 
      "according", " ", "to", " ", "the", " ", "article", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"https", ":"}]}]}], "//", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"journals", ".", "aps", ".", "org"}], "/", "prb"}], "/", 
        "abstract"}], "/", "10.1103"}], "/", "PhysRevB"}], ".76", ".104414", 
     " "}]}], "*)"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", "Va", "*)"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Options", "[", "MagnetizationsNoDL", "]"}], "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"SaturationValue", "\[Rule]", "0.199089`15"}], 
       RowBox[{"(*", 
        RowBox[{"MA", "/", "m"}], "*)"}], ",", 
       RowBox[{"CoupledValue", "\[Rule]", "0.035672`15"}]}], 
      RowBox[{"(*", 
       RowBox[{"MA", "/", "m"}], "*)"}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"MagnetizationsNoDL", "[", 
     RowBox[{"OptionsPattern", "[", "]"}], "]"}], ":=", 
    RowBox[{"Module", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Ms", "=", 
         RowBox[{"OptionValue", "[", "SaturationValue", "]"}]}], ",", 
        RowBox[{"Mc", "=", 
         RowBox[{"OptionValue", "[", "CoupledValue", "]"}]}], ",", "res", ",",
         "M1", ",", "M2"}], "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"{", "res", "}"}], "=", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"M1", ",", "M2"}], "}"}], "/.", 
         RowBox[{"Solve", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{"M1", "+", "M2"}], "\[Equal]", "Ms"}], ",", 
             RowBox[{
              RowBox[{"M1", "-", "M2"}], "\[Equal]", "Mc"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"M1", ",", "M2"}], "}"}]}], "]"}]}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"Return", "[", 
        RowBox[{"res", ",", "Module"}], "]"}], ";"}]}], "\[IndentingNewLine]",
      "]"}]}], "\[IndentingNewLine]", 
   RowBox[{"m1NoDL", "=", 
    RowBox[{
     RowBox[{"MagnetizationsNoDL", "[", "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}]}], "\[IndentingNewLine]", 
   RowBox[{"m2NoDL", "=", 
    RowBox[{
     RowBox[{"MagnetizationsNoDL", "[", "]"}], "[", 
     RowBox[{"[", "2", "]"}], "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.7304537312318144`*^9, 3.7304540585681686`*^9}, {
   3.730454099036519*^9, 3.730454110531895*^9}, {3.730481210133524*^9, 
   3.7304812631795244`*^9}, {3.7306273470556636`*^9, 
   3.7306273605216713`*^9}, {3.730642938976542*^9, 3.7306429658052163`*^9}, {
   3.7307168366554747`*^9, 3.7307168571933975`*^9}, 3.7307170170935388`*^9, {
   3.7307834494013724`*^9, 3.73078345670737*^9}, {3.730783533178043*^9, 
   3.7307835358251123`*^9}, {3.7308277415140653`*^9, 3.730827743214142*^9}, {
   3.7308278579643507`*^9, 3.730827859934882*^9}, {3.7308953002524624`*^9, 
   3.730895328041379*^9}, {3.7308965998971195`*^9, 3.7308966312070484`*^9}, {
   3.732687695692503*^9, 3.73268772304924*^9}, {3.7326886301584578`*^9, 
   3.732688676178008*^9}, {3.7326888486119423`*^9, 3.7326889929178624`*^9}, {
   3.732725060752714*^9, 3.7327250686453056`*^9}, {3.7327256531431694`*^9, 
   3.732725657900902*^9}, {3.7327257073735933`*^9, 3.732725709927734*^9}, {
   3.7428027537522087`*^9, 3.7428027825659046`*^9}, 3.7428028565063868`*^9},
 ExpressionUUID -> "811be3fd-f1ed-48bb-be21-237c974d3331"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{
    "Minimization", " ", "of", " ", "total", " ", "energy", " ", "by", " ", 
     "angles", " ", "and", " ", "constructing", " ", "a", " ", "function", 
     " ", "of", " ", "J1"}], ",", 
    RowBox[{"J2", " ", 
     RowBox[{"(", "interpolated", ")"}]}]}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Options", "[", "MHloop", "]"}], "=", "\[IndentingNewLine]", 
     RowBox[{"{", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Thickness1", "\[Rule]", 
        RowBox[{"pt1", "*", 
         SuperscriptBox["10", "6"]}]}], ",", "\[IndentingNewLine]", 
       RowBox[{"Thickness2", "->", 
        RowBox[{"pt2", "*", 
         SuperscriptBox["10", "6"]}]}], ",", "\[IndentingNewLine]", 
       RowBox[{"Magnetization1", "\[Rule]", 
        RowBox[{"(*", "m1", "*)"}], "m1NoDL"}], ",", 
       RowBox[{"(*", 
        RowBox[{"MA", "/", "m"}], "*)"}], "\[IndentingNewLine]", 
       RowBox[{"Magnetization2", "\[Rule]", 
        RowBox[{"(*", "m2", "*)"}], "m2NoDL"}], ",", 
       RowBox[{"(*", 
        RowBox[{"MA", "/", "m"}], "*)"}], "\[IndentingNewLine]", 
       RowBox[{"SaturationMagnetization", " ", "\[Rule]", "0.8"}], ",", 
       RowBox[{"(*", 
        RowBox[{"MA", "/", "m"}], "*)"}], "\[IndentingNewLine]", 
       RowBox[{"AnisotropyEnergy", "->", "0.0003`15"}], 
       RowBox[{"(*", 
        RowBox[{"MJ", "/", 
         SuperscriptBox["m", "3"]}], "*)"}], ",", "\[IndentingNewLine]", 
       RowBox[{"FieldAngle", "->", 
        RowBox[{"N", "[", 
         RowBox[{"0.0", ",", "15"}], "]"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{"StartingField", "\[Rule]", "0.7`15"}], " ", 
       RowBox[{"(*", "T", "*)"}], ",", "\[IndentingNewLine]", 
       RowBox[{"FieldStep", "\[Rule]", "0.001`15"}]}], " ", 
      RowBox[{"(*", "T", "*)"}], "\[IndentingNewLine]", "\[IndentingNewLine]",
       "\[IndentingNewLine]", "}"}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{
     "This", " ", "does", " ", "minimization", " ", "and", " ", "builds", " ",
       "a", " ", "function", " ", "of", " ", "J1"}], ",", "J2"}], "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"MHloop", "[", 
     RowBox[{"J1_", ",", "J2_", ",", 
      RowBox[{"opts", ":", 
       RowBox[{"OptionsPattern", "[", "]"}]}]}], "]"}], ":=", 
    RowBox[{"Module", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"t1", "=", 
         RowBox[{"OptionValue", "[", "Thickness1", "]"}]}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"t2", "=", 
         RowBox[{"OptionValue", "[", "Thickness2", "]"}]}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"M1", "=", 
         RowBox[{"OptionValue", "[", "Magnetization1", "]"}]}], ",", 
        "\[IndentingNewLine]", " ", 
        RowBox[{"M2", "=", 
         RowBox[{"OptionValue", "[", "Magnetization2", "]"}]}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"Ms", "=", 
         RowBox[{"OptionValue", "[", "SaturationMagnetization", "]"}]}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"Ku", "=", 
         RowBox[{"OptionValue", "[", "AnisotropyEnergy", "]"}]}], ",", 
        RowBox[{"(*", 
         RowBox[{"MJ", "/", 
          RowBox[{"m", "^", "3"}]}], "*)"}], " ", 
        RowBox[{"(*", 
         RowBox[{"Magnetocrystalline", " ", "anisotropy", " ", "energy"}], 
         "*)"}], "\[IndentingNewLine]", 
        RowBox[{"\[Alpha]", "=", 
         RowBox[{"OptionValue", "[", "FieldAngle", "]"}]}], ",", 
        RowBox[{"(*", "rad", "*)"}], 
        RowBox[{"(*", 
         RowBox[{
          RowBox[{"Relative", " ", "to", " ", "ez"}], "-", "axis"}], "*)"}], 
        "\[IndentingNewLine]", 
        RowBox[{"Hstart", "=", 
         RowBox[{"OptionValue", "[", "StartingField", "]"}]}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"dH", "=", 
         RowBox[{"OptionValue", "[", "FieldStep", "]"}]}], ",", 
        "\[IndentingNewLine]", "B", ",", "Ez1", ",", "Ez2", ",", "Eex", ",", 
        "Etot", ",", "minima", ",", "\[Psi]1", ",", "\[Psi]2", ",", 
        "\[Psi]1eq", ",", "\[Psi]2eq", ",", "ApproximationFunc", ",", 
        "Magnetizationtable"}], "\[IndentingNewLine]", "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"(*", 
       RowBox[{"Zeeman", " ", "energies"}], "*)"}], "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Ez1", "=", 
        RowBox[{
         RowBox[{"Ku", "*", 
          SuperscriptBox[
           RowBox[{"Sin", "[", "\[Psi]1", "]"}], "2"]}], "-", 
         RowBox[{"Ms", "*", "B", "*", 
          RowBox[{"Cos", "[", 
           RowBox[{"\[Alpha]", "-", "\[Psi]1"}], "]"}]}]}]}], ";", " ", 
       RowBox[{"Ez2", "=", 
        RowBox[{
         RowBox[{"Ku", "*", 
          SuperscriptBox[
           RowBox[{"Sin", "[", "\[Psi]2", "]"}], "2"]}], "-", 
         RowBox[{"Ms", "*", "B", "*", 
          RowBox[{"Cos", "[", 
           RowBox[{"\[Alpha]", "-", "\[Psi]2"}], "]"}]}]}]}], ";", " ", 
       "\[IndentingNewLine]", 
       RowBox[{"(*", 
        RowBox[{"Interlayer", " ", "Exchange", " ", "energy"}], "*)"}], 
       "\[IndentingNewLine]", 
       RowBox[{"Eex", "=", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "J1"}], "*", 
          RowBox[{"Cos", "[", 
           RowBox[{"\[Psi]1", "-", "\[Psi]2"}], "]"}]}], "-", 
         RowBox[{"J2", "*", 
          SuperscriptBox[
           RowBox[{"Cos", "[", 
            RowBox[{"\[Psi]1", "-", "\[Psi]2"}], "]"}], "2"]}]}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"(*", 
        RowBox[{"Total", " ", "energy"}], "*)"}], "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"Etot", "[", 
         RowBox[{"\[Psi]1_", ",", "\[Psi]2_"}], "]"}], ":=", 
        RowBox[{
         RowBox[{"Ez1", "*", "t1"}], "+", 
         RowBox[{"Ez2", "*", "t2"}], "+", "Eex"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"(*", 
        RowBox[{
        "Other", " ", "minimization", " ", "functions", " ", "commented"}], 
        "*)"}], "\[IndentingNewLine]", 
       RowBox[{"(*", 
        RowBox[{
         RowBox[{"minima", "=", 
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"fieldTesla", ",", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{"\[Psi]1", ",", "\[Psi]2"}], "}"}], "/.", 
               RowBox[{"Last", "[", 
                RowBox[{"FindMinimum", "[", 
                 RowBox[{
                  RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"Etot", "[", 
                    RowBox[{"\[Psi]1", ",", "\[Psi]2"}], "]"}], "/.", 
                    RowBox[{"B", "\[Rule]", "fieldTesla"}]}], ",", 
                    RowBox[{"0", "\[LessEqual]", "\[Psi]1", "<", 
                    RowBox[{"N", "[", 
                    RowBox[{
                    RowBox[{"2", "*", "Pi"}], ",", "30"}], "]"}]}], ",", 
                    RowBox[{"0", "\[LessEqual]", "\[Psi]2", "<", 
                    RowBox[{"N", "[", 
                    RowBox[{
                    RowBox[{"2", "*", "Pi"}], ",", "30"}], "]"}]}]}], "}"}], 
                  ",", 
                  RowBox[{"{", 
                   RowBox[{"\[Psi]1", ",", "\[Psi]2"}], "}"}], ",", 
                  RowBox[{"AccuracyGoal", "\[Rule]", "10"}], ",", 
                  RowBox[{"PrecisionGoal", "\[Rule]", "10"}], ",", 
                  RowBox[{"WorkingPrecision", "\[Rule]", "31"}]}], "]"}], 
                "]"}]}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"fieldTesla", ",", "0.7`30", ",", 
              RowBox[{"-", "0.7`30"}], ",", 
              RowBox[{"-", "0.001`30"}]}], "}"}]}], "]"}]}], ";"}], "*)"}], 
       "\[IndentingNewLine]", 
       RowBox[{"minima", "=", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"fieldTesla", ",", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"\[Psi]1", ",", "\[Psi]2"}], "}"}], "/.", 
             RowBox[{"Last", "[", 
              RowBox[{"NMinimize", "[", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"Etot", "[", 
                    RowBox[{"\[Psi]1", ",", "\[Psi]2"}], "]"}], "/.", 
                   RowBox[{"B", "\[Rule]", "fieldTesla"}]}], ",", 
                  RowBox[{"0`15", "<=", "\[Psi]1", "<=", 
                   RowBox[{"N", "[", 
                    RowBox[{
                    RowBox[{"2", "*", "Pi"}], ",", "15"}], "]"}]}], ",", 
                  RowBox[{"0`15", "<=", "\[Psi]2", "<=", 
                   RowBox[{"N", "[", 
                    RowBox[{
                    RowBox[{"2", "*", "Pi"}], ",", "15"}], "]"}]}]}], "}"}], 
                ",", 
                RowBox[{"{", 
                 RowBox[{"\[Psi]1", ",", "\[Psi]2"}], "}"}], ",", 
                RowBox[{"MaxIterations", "\[Rule]", "10000"}], ",", " ", 
                RowBox[{"WorkingPrecision", "\[Rule]", "15"}]}], "]"}], 
              "]"}]}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"fieldTesla", ",", "Hstart", ",", 
            RowBox[{"-", "Hstart"}], ",", 
            RowBox[{
             RowBox[{"Sign", "[", 
              RowBox[{"-", "Hstart"}], "]"}], "*", "dH"}]}], "}"}]}], "]"}]}],
        ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"(*", 
        RowBox[{"Normalized", " ", "magnetization", " ", "approximation"}], 
        "*)"}], "\[IndentingNewLine]", 
       RowBox[{"ApproximationFunc", "=", 
        FractionBox[
         RowBox[{
          RowBox[{"M1", "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"\[Psi]1eq", "-", "\[Alpha]"}], "]"}]}], "+", 
          RowBox[{"M2", "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"\[Psi]2eq", "-", "\[Alpha]"}], "]"}]}]}], 
         RowBox[{"M1", "+", "M2"}]]}], ";", "\[IndentingNewLine]", 
       RowBox[{"Magnetizationtable", "=", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"minima", "[", 
             RowBox[{"[", 
              RowBox[{"i", ",", "1"}], "]"}], "]"}], ",", 
            RowBox[{"ApproximationFunc", "/.", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"\[Psi]1eq", "->", 
                RowBox[{
                 RowBox[{"minima", "[", 
                  RowBox[{"[", 
                   RowBox[{"i", ",", "2"}], "]"}], "]"}], "[", 
                 RowBox[{"[", "1", "]"}], "]"}]}], ",", 
               RowBox[{"\[Psi]2eq", "->", 
                RowBox[{
                 RowBox[{"minima", "[", 
                  RowBox[{"[", 
                   RowBox[{"i", ",", "2"}], "]"}], "]"}], "[", 
                 RowBox[{"[", "2", "]"}], "]"}]}]}], "}"}]}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "1", ",", 
            RowBox[{"Length", "[", "minima", "]"}]}], "}"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"Return", "[", 
        RowBox[{"Magnetizationtable", ",", "Module"}], "]"}]}]}], 
     "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{
       RowBox[{"Magnetizationfunc", " ", "=", 
        RowBox[{"Interpolation", "[", "Magnetizationtable", "]"}]}], ";"}], 
      "*)"}], "\[IndentingNewLine]", "]"}]}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.7293209859114203`*^9, 3.729321013309265*^9}, {
   3.729321047967413*^9, 3.7293210960302*^9}, {3.7293211276973963`*^9, 
   3.7293211660315514`*^9}, {3.7293212895560007`*^9, 
   3.7293216484348974`*^9}, {3.7293217447193956`*^9, 
   3.7293217808785343`*^9}, {3.7293219474634886`*^9, 
   3.7293221528441153`*^9}, {3.7293243491746936`*^9, 3.72932434957275*^9}, 
   3.7293246925113244`*^9, {3.7293247229081416`*^9, 3.7293247797431316`*^9}, {
   3.7293249643422766`*^9, 3.729325037729933*^9}, {3.729325076184202*^9, 
   3.729325129658348*^9}, {3.729326581739665*^9, 3.7293268141858997`*^9}, {
   3.729326895911561*^9, 3.7293273532816715`*^9}, {3.729327487176317*^9, 
   3.729327618811303*^9}, {3.7293281621279106`*^9, 3.7293281654648046`*^9}, {
   3.729330882469883*^9, 3.72933109255126*^9}, {3.7293311483325357`*^9, 
   3.7293312024273615`*^9}, {3.729331271453258*^9, 3.7293313372451725`*^9}, {
   3.729331370192772*^9, 3.729331384455597*^9}, {3.729331417739093*^9, 
   3.7293314193343267`*^9}, {3.7293315004452653`*^9, 3.7293316089055634`*^9}, 
   3.7293316521826267`*^9, {3.7293318802218924`*^9, 3.7293319241536827`*^9}, {
   3.7293319625443926`*^9, 3.729332054402695*^9}, {3.7293320975790987`*^9, 
   3.729332123049988*^9}, {3.7293321921953287`*^9, 3.7293322187626853`*^9}, {
   3.729332287925046*^9, 3.729332336235719*^9}, {3.7293323668891516`*^9, 
   3.7293323904767523`*^9}, {3.729332447177934*^9, 3.7293324967349305`*^9}, {
   3.7293325783477454`*^9, 3.7293326008205357`*^9}, {3.729332638128536*^9, 
   3.729332661866377*^9}, {3.72933276260126*^9, 3.7293327683279486`*^9}, {
   3.7293329483055377`*^9, 3.729333004247608*^9}, {3.7293330344150677`*^9, 
   3.7293330700371614`*^9}, 3.729333185059953*^9, {3.729333451115859*^9, 
   3.7293334749551277`*^9}, {3.729333564330291*^9, 3.7293336615968866`*^9}, {
   3.7293337209761114`*^9, 3.7293337216579237`*^9}, 3.7293419118616333`*^9, {
   3.7293507115667377`*^9, 3.7293507765708933`*^9}, {3.729350875962558*^9, 
   3.7293509409236064`*^9}, {3.7293510491683655`*^9, 
   3.7293511346814966`*^9}, {3.729351171158905*^9, 3.7293512489359035`*^9}, {
   3.729351290503873*^9, 3.7293513712478094`*^9}, {3.729351424609253*^9, 
   3.729351425918763*^9}, {3.729351466298067*^9, 3.72935146800809*^9}, {
   3.7293515617945414`*^9, 3.729351605806424*^9}, {3.729352072604698*^9, 
   3.7293520786773405`*^9}, {3.729352118081852*^9, 3.729352137274881*^9}, {
   3.7293522005290585`*^9, 3.729352252587469*^9}, {3.7293530857458773`*^9, 
   3.7293531158920283`*^9}, {3.7293531737017307`*^9, 
   3.7293531928576884`*^9}, {3.729353244419752*^9, 3.729353339621891*^9}, {
   3.7293536465946693`*^9, 3.7293536468102427`*^9}, {3.7293536872096553`*^9, 
   3.7293538639465556`*^9}, {3.729353925575411*^9, 3.7293539739199467`*^9}, {
   3.729354220903617*^9, 3.7293542241181636`*^9}, {3.729354306509221*^9, 
   3.729354310353469*^9}, {3.729354352586732*^9, 3.729354485960374*^9}, {
   3.7293579356731825`*^9, 3.7293579478555994`*^9}, {3.729357992217521*^9, 
   3.7293580132905474`*^9}, {3.729358105641667*^9, 3.7293581073973274`*^9}, {
   3.729358148397317*^9, 3.72935816401484*^9}, {3.7293582137150087`*^9, 
   3.729358374845764*^9}, {3.7293586080317197`*^9, 3.729358660268605*^9}, {
   3.7293587079714622`*^9, 3.7293587620472097`*^9}, {3.7293588027514324`*^9, 
   3.729358814954879*^9}, {3.729358860772696*^9, 3.729359041333*^9}, {
   3.729359153420933*^9, 3.729359174395699*^9}, {3.7293593201874647`*^9, 
   3.7293593529706273`*^9}, {3.729359965365877*^9, 3.729359970665968*^9}, 
   3.7293600326597953`*^9, {3.7293602628437986`*^9, 3.7293602637261443`*^9}, {
   3.7293603007034893`*^9, 3.7293603115051775`*^9}, {3.7293606567319613`*^9, 
   3.729360680663261*^9}, {3.7293639618930173`*^9, 3.7293639742679195`*^9}, {
   3.7293641637136364`*^9, 3.729364166464951*^9}, 3.7293641973370047`*^9, 
   3.7293646439061956`*^9, {3.729364812956624*^9, 3.729364830578477*^9}, {
   3.7293649013967657`*^9, 3.7293649787975826`*^9}, {3.7293650331951857`*^9, 
   3.729365119449515*^9}, {3.7293651695727797`*^9, 3.7293651716593285`*^9}, {
   3.7293652719640136`*^9, 3.7293652976435394`*^9}, {3.7293655166147337`*^9, 
   3.7293655560183043`*^9}, {3.729923588479156*^9, 3.7299235956983495`*^9}, {
   3.7299238048694844`*^9, 3.729923805075031*^9}, {3.729923841572713*^9, 
   3.7299238435920887`*^9}, {3.7299240292317743`*^9, 3.729924099387301*^9}, {
   3.7299244524351788`*^9, 3.7299244645734797`*^9}, {3.7299244946253524`*^9, 
   3.729924518028507*^9}, {3.729925007108632*^9, 3.729925022733162*^9}, {
   3.7299250540975513`*^9, 3.7299251260578775`*^9}, {3.7299291619851027`*^9, 
   3.7299292621484118`*^9}, {3.729929501139019*^9, 3.7299295271020317`*^9}, {
   3.7299295843191586`*^9, 3.7299296428026514`*^9}, {3.7299296728184566`*^9, 
   3.7299297549909325`*^9}, {3.729929817706707*^9, 3.729929823860068*^9}, {
   3.7299299059863925`*^9, 3.7299299517631016`*^9}, {3.729930063242821*^9, 
   3.7299301122882223`*^9}, {3.7299302117316165`*^9, 
   3.7299302251342444`*^9}, {3.729930276554825*^9, 3.7299302793893585`*^9}, {
   3.7299303393126836`*^9, 3.7299304010809183`*^9}, {3.7299304346531496`*^9, 
   3.7299304372941723`*^9}, {3.729930558997752*^9, 3.7299305604907484`*^9}, {
   3.72993078188037*^9, 3.72993083588192*^9}, {3.7299308735230246`*^9, 
   3.729930948606628*^9}, {3.7299310606595497`*^9, 3.729931124386985*^9}, 
   3.729931166585207*^9, {3.7299312174111843`*^9, 3.7299312188710938`*^9}, {
   3.729931257327338*^9, 3.729931280970199*^9}, {3.729931336616149*^9, 
   3.72993135607987*^9}, {3.729931456304343*^9, 3.7299314644620323`*^9}, {
   3.7299317676982636`*^9, 3.729931768981676*^9}, {3.7299320007041225`*^9, 
   3.72993204698818*^9}, {3.7299324354392204`*^9, 3.7299326447767973`*^9}, {
   3.7299328222494*^9, 3.7299328780568085`*^9}, 3.7299332729949517`*^9, {
   3.7299333836202793`*^9, 3.7299335786277566`*^9}, {3.7299336713532915`*^9, 
   3.729933736259862*^9}, {3.7299338019909067`*^9, 3.7299338037726727`*^9}, {
   3.7299338345314493`*^9, 3.7299338519367304`*^9}, {3.7299339107124977`*^9, 
   3.7299339129725366`*^9}, 3.729933958277989*^9, {3.7299340209506197`*^9, 
   3.729934110471607*^9}, {3.7299342018706408`*^9, 3.729934292371234*^9}, {
   3.7299344369339104`*^9, 3.72993445161191*^9}, {3.729934506085743*^9, 
   3.7299345473143597`*^9}, {3.729934612930845*^9, 3.729934636540591*^9}, {
   3.729934744539734*^9, 3.7299347859598627`*^9}, {3.729934830936472*^9, 
   3.7299348986184254`*^9}, {3.7299349386478233`*^9, 
   3.7299349847895317`*^9}, {3.7299351372789636`*^9, 3.729935144155218*^9}, {
   3.729935193157532*^9, 3.7299352054862947`*^9}, {3.7299352499304757`*^9, 
   3.7299353037555833`*^9}, {3.7299353629549522`*^9, 3.729935365300214*^9}, {
   3.7299353991020594`*^9, 3.7299354022634935`*^9}, {3.729935443316032*^9, 
   3.729935476498228*^9}, {3.7299355471921864`*^9, 3.729935556914034*^9}, {
   3.7299355882212987`*^9, 3.7299358301339917`*^9}, 3.7299358925950317`*^9, 
   3.7299359302989564`*^9, {3.7299359758721514`*^9, 3.7299360781580772`*^9}, {
   3.729936128240234*^9, 3.729936135345153*^9}, {3.7299363023427963`*^9, 
   3.7299363424233675`*^9}, 3.7299364230186443`*^9, {3.729936487779856*^9, 
   3.729936488580986*^9}, {3.7299365441657443`*^9, 3.729936547296067*^9}, {
   3.7299366435388002`*^9, 3.729936667999864*^9}, 3.7299371077460127`*^9, 
   3.729937141126766*^9, 3.7299371857082963`*^9, {3.729937894925065*^9, 
   3.729937922837278*^9}, 3.729937953109764*^9, {3.729938007823205*^9, 
   3.729938020829815*^9}, {3.7299380526133184`*^9, 3.7299380598916435`*^9}, 
   3.7299380993405285`*^9, 3.7299384054309464`*^9, 3.7299384740252943`*^9, 
   3.72993866773155*^9, {3.729938739906446*^9, 3.7299387429545507`*^9}, {
   3.7299409603784013`*^9, 3.7299409760289817`*^9}, {3.729941228027403*^9, 
   3.7299413137102127`*^9}, {3.7299414341083474`*^9, 3.729941453346472*^9}, 
   3.7299416523877325`*^9, {3.7299417521188946`*^9, 3.7299417918214264`*^9}, {
   3.7299420076255226`*^9, 3.7299420121966825`*^9}, {3.7299420545071883`*^9, 
   3.7299420802445984`*^9}, {3.7299421591503887`*^9, 3.729942162902365*^9}, {
   3.7299421990946174`*^9, 3.729942232304889*^9}, {3.7299423096806135`*^9, 
   3.7299423132450895`*^9}, {3.729942390933671*^9, 3.7299423911512227`*^9}, 
   3.7299424781185603`*^9, 3.72994312942468*^9, {3.729943210519328*^9, 
   3.7299432286789722`*^9}, {3.729943385104375*^9, 3.7299433868379517`*^9}, {
   3.7299435975157857`*^9, 3.729943603282117*^9}, {3.729943677955455*^9, 
   3.7299436985101385`*^9}, {3.729952689741935*^9, 3.729952702087788*^9}, {
   3.729958785854088*^9, 3.729958786992691*^9}, {3.729958870751807*^9, 
   3.7299588971660233`*^9}, {3.7299590952193575`*^9, 3.729959100657831*^9}, 
   3.729961469386286*^9, {3.7299621333845654`*^9, 3.7299621335736856`*^9}, 
   3.729962248418306*^9, {3.729965639271676*^9, 3.729965642211252*^9}, {
   3.729966114433053*^9, 3.7299661169061832`*^9}, {3.7299661641750884`*^9, 
   3.7299663875442944`*^9}, {3.729966482212372*^9, 3.7299665384445157`*^9}, {
   3.7299678131014667`*^9, 3.729967863517296*^9}, {3.7299693919393897`*^9, 
   3.7299693931444445`*^9}, {3.729975085170754*^9, 3.7299750868250566`*^9}, {
   3.7299753088811207`*^9, 3.729975344548808*^9}, 3.7300938030003505`*^9, {
   3.7301013785351295`*^9, 3.7301013796019692`*^9}, {3.730101523169158*^9, 
   3.730101525498314*^9}, 3.730104062455353*^9, {3.730105113838559*^9, 
   3.730105114324853*^9}, {3.7301051754689803`*^9, 3.730105196677151*^9}, {
   3.7301062262167144`*^9, 3.7301062599199452`*^9}, {3.7301063209948473`*^9, 
   3.730106371318656*^9}, {3.730106434535358*^9, 3.7301064381098824`*^9}, {
   3.7301067829552746`*^9, 3.7301068007024603`*^9}, {3.730106994580603*^9, 
   3.730107077756506*^9}, {3.730107141193515*^9, 3.7301072227268376`*^9}, {
   3.7301073530037556`*^9, 3.7301074202377777`*^9}, 3.7301074657447023`*^9, {
   3.730107499274325*^9, 3.730107499858901*^9}, {3.730107829664833*^9, 
   3.7301078821831026`*^9}, {3.73010791235303*^9, 3.730107937741277*^9}, {
   3.7301080078011775`*^9, 3.7301080622683*^9}, {3.730108184577509*^9, 
   3.7301082463224072`*^9}, {3.7301084105572176`*^9, 3.730108411256076*^9}, {
   3.7301084828828897`*^9, 3.7301084835667076`*^9}, 3.7301085573166485`*^9, {
   3.730109051899516*^9, 3.730109075684436*^9}, {3.7301100257263203`*^9, 
   3.7301100288606825`*^9}, {3.730110151811551*^9, 3.730110152113353*^9}, {
   3.730110329791643*^9, 3.730110336029228*^9}, {3.7301104084427834`*^9, 
   3.7301104100159674`*^9}, {3.7301105074567113`*^9, 3.730110515813959*^9}, 
   3.730110611499335*^9, {3.730110716288945*^9, 3.7301107166649733`*^9}, 
   3.7301107843619347`*^9, 3.730111577292194*^9, {3.7301116662617426`*^9, 
   3.73011167249331*^9}, {3.730112281886674*^9, 3.730112285427087*^9}, {
   3.730112818460292*^9, 3.7301128188954773`*^9}, 3.7301128568684106`*^9, {
   3.7301129281487455`*^9, 3.7301129372449512`*^9}, {3.730112980178086*^9, 
   3.730113009903139*^9}, {3.7301130539702744`*^9, 3.730113054823574*^9}, {
   3.7301143372283964`*^9, 3.7301143701078153`*^9}, {3.730114437829871*^9, 
   3.7301144409331217`*^9}, {3.730121542600752*^9, 3.730121552899104*^9}, {
   3.7301216387564545`*^9, 3.7301216391183844`*^9}, {3.730121712767753*^9, 
   3.730121712911296*^9}, {3.7301217756195126`*^9, 3.730121777725931*^9}, {
   3.730121832519147*^9, 3.730121832689607*^9}, {3.730121885780733*^9, 
   3.7301218988183966`*^9}, {3.730121988056665*^9, 3.7301219882541904`*^9}, {
   3.7301220931272497`*^9, 3.7301220964009857`*^9}, {3.730122198683993*^9, 
   3.7301222037975893`*^9}, {3.730180721243804*^9, 3.7301807423338137`*^9}, {
   3.7301809916481457`*^9, 3.7301810080909195`*^9}, {3.7301811510081263`*^9, 
   3.7301811998640375`*^9}, 3.7301812377681155`*^9, {3.730181485070783*^9, 
   3.730181527402742*^9}, {3.730181565203728*^9, 3.7301815700441065`*^9}, {
   3.730181623941775*^9, 3.7301816550746803`*^9}, {3.730181688870844*^9, 
   3.730181727106571*^9}, {3.7301817691209345`*^9, 3.73018181970531*^9}, {
   3.7301818559756384`*^9, 3.730181856582285*^9}, {3.7301820064734964`*^9, 
   3.730182016796425*^9}, {3.7301821682670956`*^9, 3.7301821753222237`*^9}, {
   3.730182282852722*^9, 3.7301822936967263`*^9}, {3.7301824938812885`*^9, 
   3.7301825039940567`*^9}, {3.7301841301535387`*^9, 3.730184176241678*^9}, {
   3.730184690573728*^9, 3.7301847992752886`*^9}, 3.7301849175687857`*^9, 
   3.730185238488505*^9, {3.730185732564605*^9, 3.7301857326992702`*^9}, {
   3.7301862490640073`*^9, 3.73018625606539*^9}, {3.730186351996414*^9, 
   3.73018635500809*^9}, {3.7301864656735973`*^9, 3.7301864659217396`*^9}, {
   3.730193976884357*^9, 3.7301939959956155`*^9}, 3.7301941796388435`*^9, {
   3.7301942703907824`*^9, 3.7301942735480537`*^9}, 3.73019436333926*^9, {
   3.730194482053831*^9, 3.730194482243668*^9}, {3.7301946137817173`*^9, 
   3.730194618864565*^9}, {3.730194737735304*^9, 3.730194739669121*^9}, {
   3.730257865603895*^9, 3.7302578726923137`*^9}, {3.730258036404973*^9, 
   3.730258069453887*^9}, 3.730258467816771*^9, {3.7302585528369317`*^9, 
   3.730258558101875*^9}, 3.7302668276630697`*^9, {3.7302668869718885`*^9, 
   3.730266908092433*^9}, {3.730266963689334*^9, 3.7302669684622335`*^9}, 
   3.7302670322016535`*^9, 3.7302670907590876`*^9, {3.730267821930765*^9, 
   3.7302678416908083`*^9}, 3.7302776669195285`*^9, {3.7302777716543226`*^9, 
   3.730277771772896*^9}, {3.7302801885549607`*^9, 3.730280188843286*^9}, {
   3.730280454311702*^9, 3.730280463461379*^9}, 3.7302808552728176`*^9, {
   3.7302826542528396`*^9, 3.7302826574290137`*^9}, {3.7302828941489787`*^9, 
   3.7302830009127026`*^9}, {3.730283051613809*^9, 3.730283662358791*^9}, {
   3.7302838280426474`*^9, 3.730283898133317*^9}, 3.730283936201934*^9, {
   3.730283971498637*^9, 3.7302840146518755`*^9}, {3.730284311110402*^9, 
   3.7302843478467145`*^9}, {3.7302847828029776`*^9, 
   3.7302847995741105`*^9}, {3.73028483560611*^9, 3.7302848373239937`*^9}, 
   3.7302850974244375`*^9, {3.730285677025796*^9, 3.7302859171310267`*^9}, {
   3.730292916015504*^9, 3.7302929230086794`*^9}, {3.730295120239789*^9, 
   3.730295120431225*^9}, 3.7302955197818284`*^9, {3.7302956262055454`*^9, 
   3.730295626663246*^9}, {3.730295799918638*^9, 3.730295812253825*^9}, 
   3.730296115733444*^9, {3.730296624099289*^9, 3.7302966309444013`*^9}, {
   3.730296734377611*^9, 3.7302967736048512`*^9}, {3.730296823804167*^9, 
   3.7302968705703773`*^9}, {3.730296973970723*^9, 3.7302970169160943`*^9}, 
   3.730297086917553*^9, 3.7302971849802985`*^9, {3.7302975385536265`*^9, 
   3.7302975443077145`*^9}, {3.730297647380866*^9, 3.7302976636981564`*^9}, {
   3.730297732312912*^9, 3.730297740553358*^9}, {3.73029781026937*^9, 
   3.730297812444491*^9}, 3.730297913472847*^9, {3.7303430580686007`*^9, 
   3.7303430603279824`*^9}, {3.7303546484368286`*^9, 
   3.7303546732362967`*^9}, {3.730354731162524*^9, 3.7303547388680687`*^9}, {
   3.7303572562130775`*^9, 3.7303572726700444`*^9}, {3.7303573627514763`*^9, 
   3.73035736525548*^9}, {3.730359945155453*^9, 3.730359945321064*^9}, {
   3.7303736607297506`*^9, 3.730373662106265*^9}, {3.730389591639097*^9, 
   3.7303896042605715`*^9}, {3.7303900605430856`*^9, 
   3.7303900864200864`*^9}, {3.7304365251324034`*^9, 3.730436534889574*^9}, 
   3.7304368083884583`*^9, {3.7304481506244774`*^9, 3.7304481529336305`*^9}, {
   3.7304482303226347`*^9, 3.730448271808268*^9}, 3.730449853507593*^9, 
   3.7304499318762236`*^9, 3.730450085494133*^9, 3.7304501766177893`*^9, 
   3.7304504378512554`*^9, 3.7304505867619133`*^9, 3.7304507298844852`*^9, {
   3.730454130694406*^9, 3.730454135681033*^9}, 3.7304542419464045`*^9, 
   3.73045501768859*^9, {3.730467780872783*^9, 3.7304677822854304`*^9}, {
   3.730481104493702*^9, 3.7304811049639263`*^9}, {3.7304812940761366`*^9, 
   3.7304813018199434`*^9}, 3.73048333630022*^9, {3.7304835164608107`*^9, 
   3.7304835166327105`*^9}, 3.730484427345448*^9, {3.73048457720751*^9, 
   3.7304845828942327`*^9}, {3.730529737629136*^9, 3.7305297461891065`*^9}, {
   3.730613583894915*^9, 3.730613587925341*^9}, {3.7306137640368204`*^9, 
   3.730613764550764*^9}, 3.7306138920794826`*^9, {3.7306140319758043`*^9, 
   3.730614032085919*^9}, 3.7306251259895887`*^9, {3.730627409857462*^9, 
   3.730627449013036*^9}, {3.730627945782111*^9, 3.7306279459976807`*^9}, {
   3.7306281168165407`*^9, 3.7306281237339087`*^9}, {3.730643304099779*^9, 
   3.73064332041579*^9}, {3.7306436315457387`*^9, 3.7306436316872997`*^9}, 
   3.7306624982941065`*^9, 3.730663430805115*^9, {3.730713478656804*^9, 
   3.7307135603978043`*^9}, {3.7307136130859537`*^9, 
   3.7307136217553453`*^9}, {3.730713653065447*^9, 3.730713685393338*^9}, {
   3.7307137799864764`*^9, 3.730713783500862*^9}, {3.7307142180886116`*^9, 
   3.7307142619901466`*^9}, {3.7307143091888237`*^9, 3.73071431952242*^9}, 
   3.730828345838632*^9, 3.7308285704597054`*^9, {3.730828665433017*^9, 
   3.730828669620636*^9}, {3.730830016877338*^9, 3.73083001724288*^9}, 
   3.7308937336566057`*^9, 3.730894030973302*^9, 3.7308943369680076`*^9, 
   3.7308958580305204`*^9, 3.730896851017663*^9, 3.730897031987382*^9, 
   3.7308971880257764`*^9, {3.7326890059746547`*^9, 3.732689112099375*^9}, {
   3.732689413668296*^9, 3.7326895171266365`*^9}, {3.7327048110874567`*^9, 
   3.7327048381088195`*^9}, {3.732704914964746*^9, 3.732704929395095*^9}, {
   3.732705004856643*^9, 3.7327050995289955`*^9}, {3.732716637797591*^9, 
   3.7327166645969086`*^9}, {3.732716779767412*^9, 3.7327167930616035`*^9}, 
   3.732725053247648*^9, 3.7327253892920694`*^9, {3.7428020664379635`*^9, 
   3.7428021025487604`*^9}, {3.7428029097429204`*^9, 
   3.7428029412598195`*^9}, {3.742803575551222*^9, 3.7428036110057745`*^9}, {
   3.7428040552269564`*^9, 3.7428040564613967`*^9}},
 ExpressionUUID -> "eace2cbb-d074-44b4-a6ad-557ae383464b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"Interpolation", " ", 
    RowBox[{"func", ".", " ", "M"}], 
    RowBox[{
     RowBox[{"(", "H", ")"}], "/", "Ms"}]}], " ", "*)"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Options", "[", "sampandinter", "]"}], "=", 
     "\[IndentingNewLine]", 
     RowBox[{"{", "\[IndentingNewLine]", 
      RowBox[{"(*", 
       RowBox[{"replacefrom", "->", "0.05"}], 
       RowBox[{"(*", "T", "*)"}], "*)"}], 
      RowBox[{",", 
       RowBox[{"(*", 
        RowBox[{"explained", " ", "below"}], "*)"}], "\[IndentingNewLine]", 
       RowBox[{"forwsweep", "\[Rule]", "True"}]}], "\[IndentingNewLine]", 
      "\[IndentingNewLine]", "}"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"sampandinter", "[", 
     RowBox[{"J1_", ",", "J2_", ",", "dH_", ",", 
      RowBox[{"opts", ":", 
       RowBox[{"OptionsPattern", "[", "]"}]}]}], "]"}], ":=", 
    RowBox[{"Module", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"divpoint", "=", 
         RowBox[{"OptionValue", "[", "replacefrom", "]"}]}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"forwsweepflag", "=", 
         RowBox[{"OptionValue", "[", "forwsweep", "]"}]}], ",", 
        "\[IndentingNewLine]", "fixeddata", ",", "interpolation", ",", "data",
         ",", "fixeddata1", ",", "fixeddata2"}], "\[IndentingNewLine]", 
       "\[IndentingNewLine]", "}"}], ",", "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"If", "[", 
        RowBox[{"forwsweepflag", ",", "\[IndentingNewLine]", 
         RowBox[{"data", "=", 
          RowBox[{"MHloop", "[", 
           RowBox[{"J1", ",", "J2", ",", 
            RowBox[{"FieldAngle", "->", 
             RowBox[{"N", "[", 
              RowBox[{"0.0", ",", "15"}], "]"}]}], ",", 
            RowBox[{"StartingField", "\[Rule]", "0.7`15"}], ",", " ", 
            RowBox[{"FieldStep", "\[Rule]", "dH"}]}], "]"}]}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"data", "=", 
          RowBox[{"MHloop", "[", 
           RowBox[{"J1", ",", "J2", ",", 
            RowBox[{"FieldAngle", "->", 
             RowBox[{"N", "[", 
              RowBox[{
               RowBox[{"2.", "*", 
                RowBox[{"Pi", "/", "2"}]}], ",", "15"}], "]"}]}], ",", 
            RowBox[{"StartingField", "\[Rule]", 
             RowBox[{"-", "0.7`15"}]}], ",", " ", 
            RowBox[{"FieldStep", "\[Rule]", "dH"}]}], "]"}]}]}], 
        "\[IndentingNewLine]", "\[IndentingNewLine]", "]"}], ";", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"(*", 
        RowBox[{
         RowBox[{
         "This", " ", "weird", " ", "piece", " ", "is", " ", "a", " ", 
          "workaround", " ", "for", " ", "the", " ", "terrible", " ", 
          "spikes", " ", "in", " ", "numerics", " ", "I", " ", "was", " ", 
          "getting", " ", "sometimes", " ", "for", " ", "one", " ", "of", " ",
           "the", " ", "field", " ", "directions", " ", "for", " ", "now", 
          " ", "reason", "\[IndentingNewLine]", "\[IndentingNewLine]", "Due", 
          " ", "to", " ", "small", " ", "anisotropy"}], ",", " ", 
         RowBox[{
         "my", " ", "curves", " ", "were", " ", "symmetric", " ", "so", " ", 
          "I", " ", "was", " ", "just", " ", "replacing", " ", "part", " ", 
          "of", " ", "the", " ", "curve", " ", "from", " ", "its", " ", 
          "symmetric", " ", "counter", " ", 
          RowBox[{
          "part", ".", " ", "\[IndentingNewLine]", "\[IndentingNewLine]", 
           "If"}], " ", "you", " ", "dont", " ", "have", " ", "symmetric", 
          " ", "M", 
          RowBox[{"(", "H", ")"}], " ", "or", "  ", "such", " ", "troubles"}],
          ",", " ", 
         RowBox[{
         "this", " ", "is", " ", "useless", " ", "and", " ", "Should", " ", 
          "be", " ", "removed"}], ",", " ", 
         RowBox[{"so", " ", "I", " ", "will", " ", "comment", " ", "it"}]}], 
        "*)"}], "\[IndentingNewLine]", 
       RowBox[{"(*", 
        RowBox[{
         RowBox[{"fixeddata1", "=", 
          RowBox[{"Join", "[", 
           RowBox[{
            RowBox[{"Select", "[", 
             RowBox[{"data", ",", 
              RowBox[{
               RowBox[{
                RowBox[{"First", "[", "#", "]"}], "<", "divpoint"}], "&"}]}], 
             "]"}], ",", 
            RowBox[{
             RowBox[{"Select", "[", 
              RowBox[{"data", ",", 
               RowBox[{
                RowBox[{
                 RowBox[{"First", "[", "#", "]"}], "<", 
                 RowBox[{"-", "divpoint"}]}], "&"}]}], "]"}], "*", 
             RowBox[{"(", 
              RowBox[{"-", "1"}], ")"}]}]}], "]"}]}], ";", 
         "\[IndentingNewLine]", "   ", 
         RowBox[{"fixeddata2", "=", 
          RowBox[{"Join", "[", 
           RowBox[{
            RowBox[{"Select", "[", 
             RowBox[{"data", ",", 
              RowBox[{
               RowBox[{
                RowBox[{"First", "[", "#", "]"}], ">", 
                RowBox[{"-", "divpoint"}]}], "&"}]}], "]"}], ",", 
            RowBox[{
             RowBox[{"Select", "[", 
              RowBox[{"data", ",", 
               RowBox[{
                RowBox[{
                 RowBox[{"First", "[", "#", "]"}], ">", "divpoint"}], "&"}]}],
               "]"}], "*", 
             RowBox[{"(", 
              RowBox[{"-", "1"}], ")"}]}]}], "]"}]}], ";", 
         "\[IndentingNewLine]", "\[IndentingNewLine]", 
         RowBox[{"interpolation", "=", 
          RowBox[{"If", "[", 
           RowBox[{"forwsweepflag", ",", 
            RowBox[{"Interpolation", "[", "fixeddata1", "]"}], ",", 
            RowBox[{"Interpolation", "[", "fixeddata2", "]"}]}], "]"}]}], 
         ";"}], "*)"}], "\[IndentingNewLine]", 
       RowBox[{"interpolation", "=", 
        RowBox[{"Interpolation", "[", "data", "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"Return", "[", 
        RowBox[{"Function", "[", 
         RowBox[{"\[Tau]", ",", 
          RowBox[{"Evaluate", "[", 
           RowBox[{"interpolation", "[", "\[Tau]", "]"}], "]"}]}], "]"}], 
        "]"}]}]}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{
  3.730292944072968*^9, {3.7302936302478266`*^9, 3.7302936676410365`*^9}, {
   3.7302937149501953`*^9, 3.7302938354477296`*^9}, {3.7302938739075766`*^9, 
   3.7302938764023*^9}, {3.7302940814454565`*^9, 3.7302944277392673`*^9}, {
   3.730294467311283*^9, 3.730294472527598*^9}, {3.7302945207571335`*^9, 
   3.730294550801841*^9}, {3.7302945817949142`*^9, 3.730294692985523*^9}, {
   3.730294736207054*^9, 3.7302948727350817`*^9}, {3.730294916365917*^9, 
   3.730294964233961*^9}, 3.7302958704892893`*^9, {3.73029793871601*^9, 
   3.7302979536776876`*^9}, {3.730298069173976*^9, 3.7302980857934604`*^9}, {
   3.7302982062146673`*^9, 3.7302982826161795`*^9}, {3.730298510447234*^9, 
   3.730298520535123*^9}, {3.730298641109118*^9, 3.7302986472216444`*^9}, {
   3.7302987402701273`*^9, 3.7302987413212795`*^9}, {3.730298968525488*^9, 
   3.730298982155009*^9}, {3.7302992085102615`*^9, 3.7302992176204634`*^9}, {
   3.730299560656853*^9, 3.730299596973381*^9}, {3.7302997474741035`*^9, 
   3.7302997492391624`*^9}, {3.7303007687461233`*^9, 
   3.7303008331663165`*^9}, {3.7303016652147994`*^9, 
   3.7303016655799837`*^9}, {3.730301730710474*^9, 3.7303018687009463`*^9}, {
   3.7303019085255814`*^9, 3.7303019139068413`*^9}, 3.7303627465267386`*^9, {
   3.730362799273939*^9, 3.7303627994951963`*^9}, 3.7303650881182575`*^9, {
   3.7303691298622265`*^9, 3.7303691392389383`*^9}, {3.730377321376213*^9, 
   3.730377322207563*^9}, {3.730380776338705*^9, 3.730380818362465*^9}, {
   3.7303891201135826`*^9, 3.7303891510066285`*^9}, {3.7303977869959*^9, 
   3.730397800105053*^9}, {3.7303984327771864`*^9, 3.7303984328773355`*^9}, {
   3.730430306305214*^9, 3.730430318944173*^9}, {3.730430437751552*^9, 
   3.7304304416840796`*^9}, {3.7304441950237455`*^9, 
   3.7304442047679024`*^9}, {3.7304480863121214`*^9, 3.730448107288746*^9}, {
   3.7304483412551394`*^9, 3.7304483446372566`*^9}, 3.730448649229267*^9, {
   3.730449591600456*^9, 3.730449614404512*^9}, {3.7304500949903*^9, 
   3.7304501087866087`*^9}, {3.730461696648538*^9, 3.730461702936936*^9}, {
   3.7304657523556013`*^9, 3.730465761949442*^9}, {3.730466055075226*^9, 
   3.7304660566617513`*^9}, {3.7304661848023014`*^9, 
   3.7304662173819675`*^9}, {3.7304662766053405`*^9, 3.730466279345849*^9}, {
   3.730466343415315*^9, 3.730466356803155*^9}, {3.730466416227662*^9, 
   3.730466416268268*^9}, {3.730466486574288*^9, 3.7304664940251427`*^9}, {
   3.7304665763734446`*^9, 3.7304665792617755`*^9}, {3.7304668478528214`*^9, 
   3.730466849387273*^9}, 3.730467235996406*^9, {3.7304675161391215`*^9, 
   3.7304675184439125`*^9}, {3.730479838160494*^9, 3.7304798532168283`*^9}, {
   3.7304814001823673`*^9, 3.730481413059972*^9}, {3.7304831557389526`*^9, 
   3.73048315732308*^9}, {3.7304833531225557`*^9, 3.7304833578148203`*^9}, {
   3.730483526910192*^9, 3.730483528864724*^9}, 3.730487773314607*^9, {
   3.73052991442971*^9, 3.730529926318997*^9}, {3.7305308894840384`*^9, 
   3.7305308933270264`*^9}, {3.730531065687752*^9, 3.730531065817884*^9}, {
   3.7305312014813185`*^9, 3.730531204163022*^9}, {3.730573202979455*^9, 
   3.7305732218635225`*^9}, {3.730573449070639*^9, 3.730573451381706*^9}, {
   3.730573617299161*^9, 3.730573620343877*^9}, {3.730574011045047*^9, 
   3.730574019558584*^9}, {3.7305743058101597`*^9, 3.730574307939723*^9}, {
   3.730574506354356*^9, 3.730574516129058*^9}, {3.730574637457715*^9, 
   3.7305746384182835`*^9}, {3.730574751492455*^9, 3.7305747526590924`*^9}, {
   3.7305749203327665`*^9, 3.730574921543863*^9}, {3.730575050874366*^9, 
   3.730575060409436*^9}, {3.730575377134274*^9, 3.7305753851561737`*^9}, {
   3.7305755939020615`*^9, 3.7305755958084393`*^9}, {3.730615592474039*^9, 
   3.7306155953569036`*^9}, {3.730615719218609*^9, 3.7306157210206127`*^9}, {
   3.7306237692685504`*^9, 3.73062377844656*^9}, {3.730624828219952*^9, 
   3.7306248303307104`*^9}, {3.7306253849973164`*^9, 3.730625386548931*^9}, {
   3.73062548933421*^9, 3.730625490975499*^9}, {3.7306256042980576`*^9, 
   3.730625605948266*^9}, {3.730625708087364*^9, 3.7306257100989957`*^9}, {
   3.7306258357336116`*^9, 3.7306258376750917`*^9}, {3.730625937694233*^9, 
   3.7306259389656696`*^9}, {3.7306323797449465`*^9, 
   3.7306324013090973`*^9}, {3.730634310876813*^9, 3.7306343168059454`*^9}, {
   3.7306348039616585`*^9, 3.730634808644923*^9}, {3.7306370730988483`*^9, 
   3.7306370942222967`*^9}, 3.730643431399057*^9, {3.730643950014787*^9, 
   3.730643951755003*^9}, {3.7306440148093576`*^9, 3.7306440394603148`*^9}, {
   3.7306441607452474`*^9, 3.730644166829214*^9}, {3.7306442719636745`*^9, 
   3.7306442720435057`*^9}, {3.730644372342134*^9, 3.7306443739313354`*^9}, 
   3.730644582083449*^9, {3.7306447354805193`*^9, 3.730644743867338*^9}, 
   3.730651003642906*^9, 3.730651085509765*^9, 3.730651160983385*^9, 
   3.7306591613204026`*^9, 3.730659290647231*^9, {3.730659441837926*^9, 
   3.730659447977293*^9}, {3.7306614303319902`*^9, 3.7306614351611786`*^9}, 
   3.7306617505312757`*^9, {3.730662165859848*^9, 3.730662170419278*^9}, {
   3.7306623184874163`*^9, 3.73066232000288*^9}, {3.7306627188139668`*^9, 
   3.7306627226337824`*^9}, {3.7306630276698103`*^9, 
   3.7306630295528946`*^9}, {3.7306637482315903`*^9, 
   3.7306637500187416`*^9}, {3.730717162171452*^9, 3.7307171681896*^9}, {
   3.7307206756256957`*^9, 3.730720680768587*^9}, {3.730720784597643*^9, 
   3.7307207883409142`*^9}, {3.7307209044034624`*^9, 3.730720907906601*^9}, {
   3.730721043763726*^9, 3.7307210450941544`*^9}, {3.7307214828288264`*^9, 
   3.730721488884654*^9}, {3.730721589978015*^9, 3.730721593631912*^9}, {
   3.730721730833575*^9, 3.7307217353920913`*^9}, {3.7307557071923585`*^9, 
   3.7307557146211333`*^9}, {3.730755943424675*^9, 3.7307559464752216`*^9}, {
   3.7307560522586074`*^9, 3.730756062539157*^9}, {3.7307744944343967`*^9, 
   3.7307745004300146`*^9}, 3.730783693130538*^9, {3.7307837910895324`*^9, 
   3.730783795930955*^9}, {3.7307838907121434`*^9, 3.730783892883292*^9}, {
   3.7307839648432956`*^9, 3.7307839660068116`*^9}, {3.730784044062105*^9, 
   3.7307840442823668`*^9}, 3.7307841275300026`*^9, 3.730784183151896*^9, {
   3.730784288001421*^9, 3.7307842912014093`*^9}, {3.7307962314383183`*^9, 
   3.730796240229163*^9}, 3.7307963408675194`*^9, {3.7307965257578044`*^9, 
   3.7307965258378215`*^9}, {3.730796677321884*^9, 3.730796680173564*^9}, {
   3.730807931935712*^9, 3.7308079350173345`*^9}, 3.730807991583763*^9, {
   3.7308295582266397`*^9, 3.730829567493849*^9}, 3.7308296435527625`*^9, {
   3.7308297135950375`*^9, 3.7308297160623875`*^9}, {3.7308298077452087`*^9, 
   3.730829822016343*^9}, {3.7308299232974358`*^9, 3.73082992399512*^9}, 
   3.730829989698415*^9, {3.7308302207759275`*^9, 3.7308302227441587`*^9}, 
   3.7308302865728436`*^9, 3.7308304126343513`*^9, {3.730870394991108*^9, 
   3.7308703967337694`*^9}, {3.730870575261153*^9, 3.7308705823906784`*^9}, 
   3.7308707637347946`*^9, {3.7308956999391327`*^9, 3.730895703164708*^9}, {
   3.730896672739523*^9, 3.7308966784871807`*^9}, {3.7327129511830997`*^9, 
   3.7327129617236857`*^9}, {3.732716688676443*^9, 3.73271675018522*^9}, {
   3.7327255144235973`*^9, 3.732725532507756*^9}, {3.7428016622285123`*^9, 
   3.7428018818991814`*^9}, {3.7428019594648204`*^9, 
   3.7428019991226835`*^9}, {3.742802130862424*^9, 3.742802155207156*^9}, {
   3.742802185458395*^9, 3.7428022157565017`*^9}, {3.742802425265007*^9, 
   3.742802427296334*^9}, {3.742802632481666*^9, 3.7428026653580065`*^9}, {
   3.7428029956995277`*^9, 3.742803009184473*^9}, {3.742803048014159*^9, 
   3.742803071905751*^9}, {3.7428031347989197`*^9, 3.742803204223629*^9}, {
   3.742803271757631*^9, 3.7428032742108817`*^9}, {3.7428033203065023`*^9, 
   3.7428033609956727`*^9}, {3.7428033974346094`*^9, 
   3.7428034080131664`*^9}, {3.742803471062625*^9, 3.742803491985333*^9}},
 ExpressionUUID -> "6c5ef36d-9f9e-4f41-921e-c238b177f2cf"],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.7302980604690313`*^9, 3.730298119012479*^9}, {
   3.7302985434550886`*^9, 3.730298574206402*^9}, {3.7302996015005293`*^9, 
   3.7302996163639255`*^9}, {3.7303014316099453`*^9, 
   3.7303014366684875`*^9}, {3.7303014951811075`*^9, 3.730301514034203*^9}, 
   3.730362667106902*^9, {3.730389777341152*^9, 3.7303898181840677`*^9}, {
   3.730450365936552*^9, 3.730450383645505*^9}, 3.730450565546903*^9, {
   3.730461673295096*^9, 3.7304616798295665`*^9}, {3.7304661988083515`*^9, 
   3.7304662097547398`*^9}, {3.7304671104112663`*^9, 3.730467133882019*^9}, {
   3.7304672406512117`*^9, 3.730467243872158*^9}, 3.7304877417484655`*^9, {
   3.730575905142318*^9, 3.730575906645007*^9}, {3.7306249890942125`*^9, 
   3.730625107023736*^9}, {3.730625261350662*^9, 3.7306252937907443`*^9}, {
   3.7306253576753516`*^9, 3.7306253609174848`*^9}, {3.7306278225465727`*^9, 
   3.7306278237836847`*^9}, 3.7306282809528093`*^9, {3.7306435931038074`*^9, 
   3.730643598047916*^9}, {3.7306440414722834`*^9, 3.730644043293532*^9}, 
   3.7306440737507577`*^9, {3.7306592657031083`*^9, 3.7306592688359375`*^9}, 
   3.730783706504242*^9, {3.7308282502349234`*^9, 3.7308282522934484`*^9}, {
   3.7308294586826987`*^9, 3.730829463042488*^9}, {3.730870585986985*^9, 
   3.730870589032194*^9}, {3.730894229516322*^9, 3.73089424723246*^9}, {
   3.730896065813454*^9, 3.7308960972410126`*^9}, {3.7308968368875895`*^9, 
   3.7308968387974815`*^9}, {3.730897350764021*^9, 3.7308973512055054`*^9}, {
   3.7428026122620792`*^9, 3.7428026167622695`*^9}, {3.7428032095832295`*^9, 
   3.7428032104113684`*^9}},
 ExpressionUUID -> "8f628a1e-6193-475a-a02c-757a702d0c0e"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{
    "Minimization", " ", "of", " ", "the", " ", "squared", " ", "error", " ", 
     "using", " ", "different", " ", "J1"}], ",", "J2"}], "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Options", "[", "Chi2test", "]"}], "=", 
     RowBox[{"{", 
      RowBox[{"fieldstep", "\[Rule]", "0.001`15"}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Chi2test", "[", 
     RowBox[{"fsweep_", ",", "bsweep_", ",", "J1_", ",", "J2_", ",", 
      RowBox[{"OptionsPattern", "[", "]"}]}], "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"dH", "=", 
         RowBox[{"OptionValue", "[", "fieldstep", "]"}]}], ",", "i", ",", 
        "FuncForthisJsforw", ",", "FuncForthisJsback", ",", "Errorlistfsweep",
         ",", "Errorlistbsweep", ",", "Chi2error", ",", "Errorlistwithpar", 
        ",", "Errorlist"}], "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"FuncForthisJsforw", "=", 
        RowBox[{"sampandinter", "[", 
         RowBox[{"J1", ",", "J2", ",", "dH", ",", 
          RowBox[{"forwsweep", "\[Rule]", "True"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"FuncForthisJsback", "=", 
        RowBox[{"sampandinter", "[", 
         RowBox[{"J1", ",", "J2", ",", "dH", ",", 
          RowBox[{"forwsweep", "\[Rule]", "False"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"Errorlistfsweep", "=", 
        RowBox[{"Table", "[", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"FuncForthisJsforw", "[", 
              RowBox[{"fsweep", "[", 
               RowBox[{"[", 
                RowBox[{"i", ",", "1"}], "]"}], "]"}], "]"}], "-", 
             RowBox[{"fsweep", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "2"}], "]"}], "]"}]}], ")"}], "2"], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "1", ",", 
            RowBox[{"Length", "[", "fsweep", "]"}]}], "}"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"(*", 
        RowBox[{
         RowBox[{"Errorlistwithpar", "=", 
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"i", ",", 
              RowBox[{"Sqrt", "[", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"testintfunc", "[", 
                    RowBox[{"a", ",", "b"}], "]"}], "[", 
                   RowBox[{"data", "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "1"}], "]"}], "]"}], "]"}], "-", 
                  RowBox[{"data", "[", 
                   RowBox[{"[", 
                    RowBox[{"i", ",", "2"}], "]"}], "]"}]}], ")"}], "2"], 
               "]"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"i", ",", "1", ",", 
              RowBox[{"Length", "[", "data", "]"}]}], "}"}]}], "]"}]}], ";"}],
         "*)"}], "\[IndentingNewLine]", 
       RowBox[{"Errorlistbsweep", "=", 
        RowBox[{"Table", "[", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"FuncForthisJsback", "[", 
              RowBox[{"bsweep", "[", 
               RowBox[{"[", 
                RowBox[{"i", ",", "1"}], "]"}], "]"}], "]"}], "-", 
             RowBox[{"bsweep", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "2"}], "]"}], "]"}]}], ")"}], "2"], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "1", ",", 
            RowBox[{"Length", "[", "bsweep", "]"}]}], "}"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"Errorlist", "=", 
        RowBox[{"Join", "[", 
         RowBox[{"Errorlistfsweep", ",", "Errorlistbsweep"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"Chi2error", "=", 
        RowBox[{"Total", "[", "Errorlist", "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"Return", "[", 
        RowBox[{"Chi2error", ",", "Module"}], "]"}]}]}], 
     "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{
     "Single", " ", "error", " ", "test", " ", "with", " ", "definite", " ", 
      "J1"}], ",", " ", 
     RowBox[{"J2", " ", "in", " ", 
      RowBox[{"J", "/", 
       SuperscriptBox["m", "2"]}], " ", 
      RowBox[{"(", 
       RowBox[{
       "if", " ", "its", " ", "not", " ", "completely", " ", "off"}]}]}]}], 
    "*)"}], "\[IndentingNewLine]", 
   RowBox[{"Chi2test", "[", 
    RowBox[{"ForwSweep", ",", "BackSweep", ",", 
     RowBox[{"-", "0.000047`15"}], ",", 
     RowBox[{"-", "0.000005`15"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.7302999216866035`*^9, 3.7302999456422405`*^9}, {
   3.730300086701704*^9, 3.7303000975579805`*^9}, {3.7303002748143225`*^9, 
   3.730300328423291*^9}, {3.730300414880454*^9, 3.730300425376156*^9}, {
   3.7303004865166135`*^9, 3.7303005842349367`*^9}, {3.7303006271408377`*^9, 
   3.7303006961361957`*^9}, {3.730300734424465*^9, 3.730300736209135*^9}, {
   3.7303009235990834`*^9, 3.7303010963531475`*^9}, 3.730301131922965*^9, 
   3.7303431991067467`*^9, {3.73034355147365*^9, 3.730343584235338*^9}, 
   3.730343751288047*^9, {3.730345215163646*^9, 3.7303453102779493`*^9}, {
   3.730345378457849*^9, 3.730345447317193*^9}, {3.730345663991143*^9, 
   3.7303456759922485`*^9}, 3.730345736068678*^9, 3.7303457765246677`*^9, 
   3.73036285037795*^9, 3.7303737176745996`*^9, {3.7304666935621357`*^9, 
   3.7304667021620083`*^9}, 3.7304673528845816`*^9, {3.7304681202952976`*^9, 
   3.7304681207554846`*^9}, {3.7304755273682914`*^9, 3.73047553175209*^9}, {
   3.7306344118376093`*^9, 3.730634418250849*^9}, 3.730634872062109*^9, 
   3.7306350063152194`*^9, {3.7327167677000313`*^9, 3.7327167703193154`*^9}, {
   3.732716801594396*^9, 3.7327168207817717`*^9}, {3.7428023481681213`*^9, 
   3.742802388826014*^9}, 3.7428025268941355`*^9, {3.742803436404946*^9, 
   3.742803441483267*^9}},
 ExpressionUUID -> "83a5dcba-a9cb-4d2f-afbe-07b493e2c824"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"result", "=", 
    RowBox[{"Flatten", "[", 
     RowBox[{
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"J1", ",", "J2", ",", 
          RowBox[{"Chi2test", "[", 
           RowBox[{"ForwSweep", ",", "BackSweep", ",", "J1", ",", "J2"}], 
           "]"}]}], "}"}], ",", 
        RowBox[{"(*", 
         RowBox[{
          RowBox[{"Desired", " ", "ranges", " ", "of", " ", "J1"}], ",", " ", 
          RowBox[{
          "J2", " ", "and", " ", "corresponding", " ", "step", " ", "in", " ", 
           RowBox[{"J", "/", 
            SuperscriptBox["m", "2"]}]}]}], "*)"}], 
        RowBox[{"{", 
         RowBox[{"J1", ",", 
          RowBox[{"-", "0.000131`15"}], ",", 
          RowBox[{"-", "0.000120`15"}], ",", "0.000001`15"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"J2", ",", 
          RowBox[{"-", "0.00001`15"}], ",", "0.000003`15", ",", 
          "0.000001`15"}], "}"}]}], "]"}], ",", "1"}], "]"}]}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.730302130940551*^9, 3.730302322479164*^9}, 
   3.7303024687141027`*^9, {3.7303025835520043`*^9, 3.7303025839280105`*^9}, {
   3.73034728228041*^9, 3.7303472847893*^9}, {3.7303598420407286`*^9, 
   3.7303598875961175`*^9}, {3.7303735783421125`*^9, 3.730373627497533*^9}, {
   3.730374358545618*^9, 3.7303743739474154`*^9}, {3.730377257272169*^9, 
   3.7303772896268597`*^9}, {3.7303807378190317`*^9, 3.730380749140131*^9}, {
   3.730380986240074*^9, 3.7303810032178636`*^9}, {3.7303865838103857`*^9, 
   3.730386592127701*^9}, 3.7303866243066626`*^9, {3.730390470867075*^9, 
   3.7303905076355567`*^9}, {3.7303907570950885`*^9, 3.730390761534176*^9}, 
   3.7303919154398513`*^9, {3.730394387500513*^9, 3.730394430401535*^9}, {
   3.7303985708390627`*^9, 3.7303985889975014`*^9}, {3.730401726884011*^9, 
   3.7304017420645943`*^9}, {3.730427185679654*^9, 3.7304272592383776`*^9}, {
   3.7304288597213697`*^9, 3.7304288646953125`*^9}, {3.7304374572745347`*^9, 
   3.730437504447682*^9}, {3.7304395770150414`*^9, 3.730439588711079*^9}, 
   3.7304422731213083`*^9, {3.7304441440115814`*^9, 3.7304441657604914`*^9}, {
   3.7304542662408967`*^9, 3.7304543140101786`*^9}, {3.7304586561647563`*^9, 
   3.730458663724324*^9}, {3.7304618840499005`*^9, 3.730461952572753*^9}, {
   3.7304682917696524`*^9, 3.730468346286669*^9}, {3.730471228992666*^9, 
   3.7304712447997384`*^9}, {3.73047658481073*^9, 3.7304766879791145`*^9}, 
   3.7304773692461452`*^9, {3.7304787306709805`*^9, 3.7304787377019625`*^9}, {
   3.7305301135559063`*^9, 3.730530232626479*^9}, {3.7305305785456195`*^9, 
   3.730530598598768*^9}, {3.7305310352371006`*^9, 3.730531041932975*^9}, {
   3.730531412361767*^9, 3.7305314219293776`*^9}, {3.73053233956629*^9, 
   3.7305323780395374`*^9}, {3.7305324617818065`*^9, 3.7305325062539673`*^9}, 
   3.7305461944708967`*^9, {3.730616004966691*^9, 3.730616064586711*^9}, {
   3.7306283820699034`*^9, 3.730628449527236*^9}, {3.730628695516351*^9, 
   3.7306287148434944`*^9}, 3.730630213885419*^9, {3.7306303123804197`*^9, 
   3.7306303274885545`*^9}, {3.73063259490718*^9, 3.730632628768565*^9}, {
   3.730635233531337*^9, 3.730635239426644*^9}, {3.730645050545396*^9, 
   3.73064505718893*^9}, {3.73064508812928*^9, 3.730645177456481*^9}, {
   3.7306452401576157`*^9, 3.730645243419714*^9}, {3.730645277130934*^9, 
   3.730645277210763*^9}, {3.7306453081670823`*^9, 3.7306453347036033`*^9}, {
   3.730659623984748*^9, 3.730659659658566*^9}, {3.730660014930111*^9, 
   3.7306600391711197`*^9}, {3.730722159202797*^9, 3.7307221669832077`*^9}, {
   3.730722349018626*^9, 3.730722380855348*^9}, {3.7307562336160526`*^9, 
   3.730756250998677*^9}, {3.7307563123987646`*^9, 3.7307563318921933`*^9}, {
   3.7307844065071254`*^9, 3.7307844163991027`*^9}, {3.730784473151582*^9, 
   3.7307845202012835`*^9}, {3.7307965131896996`*^9, 
   3.7307965195316205`*^9}, {3.730796599363626*^9, 3.730796611239366*^9}, {
   3.7307966568650155`*^9, 3.7307966570752707`*^9}, {3.7308081678446903`*^9, 
   3.730808179155819*^9}, {3.7308104583182154`*^9, 3.7308104584783077`*^9}, {
   3.730814006554376*^9, 3.730814026315057*^9}, {3.7308304975983553`*^9, 
   3.7308305093018017`*^9}, {3.730855162688094*^9, 3.730855171440923*^9}, {
   3.7327254404629846`*^9, 3.732725441395341*^9}, {3.7428014524634433`*^9, 
   3.7428015021681585`*^9}, {3.7428024074205313`*^9, 
   3.7428024080611815`*^9}, {3.7428034281546297`*^9, 3.7428034292640285`*^9}},
 ExpressionUUID -> "942fd965-c375-493a-95b1-6d74ca74d0c3"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"ListPlot", "[", "testreer", "]"}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
   "Minimum", " ", "of", " ", "the", " ", "error", " ", "will", " ", 
    "correspond", " ", "to", " ", "best", " ", "fitting"}], "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"ListContourPlot", "[", "result", "]"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{
     "Its", " ", "a", " ", "test", " ", "plotting", " ", "with", " ", 
      "definite", " ", "values", " ", "of", " ", "J1"}], ",", 
     RowBox[{"J2", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"found", " ", "from", " ", "previous", " ", "step"}], ")"}], 
       ".", " ", "It"}], " ", "is", " ", "there", " ", "to", " ", "see", " ", 
      "how", " ", "good", " ", "is", " ", "the", " ", "fitting"}]}], "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"testfunc1sweep", "=", 
     RowBox[{"sampandinter", "[", 
      RowBox[{
       RowBox[{"-", "0.000064`14"}], ",", 
       RowBox[{"-", "0.000004`15"}], ",", "0.001`15", ",", 
       RowBox[{"forwsweep", "\[Rule]", "True"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"testfunc2sweep", "=", 
     RowBox[{"sampandinter", "[", 
      RowBox[{
       RowBox[{"-", "0.000064`14"}], ",", 
       RowBox[{"-", "0.000004`15"}], ",", "0.001`15", ",", 
       RowBox[{"forwsweep", "\[Rule]", "False"}]}], "]"}]}], 
    ";"}]}]}]], "Input",
 CellChangeTimes->{{3.7305322234984455`*^9, 3.7305322739959507`*^9}, {
   3.7306302168974314`*^9, 3.7306302319511056`*^9}, {3.7306450619684906`*^9, 
   3.7306450663698363`*^9}, {3.730659669223768*^9, 3.7306596758065405`*^9}, {
   3.7307221769212704`*^9, 3.7307221811638565`*^9}, 3.732725452986842*^9, {
   3.7428015160164876`*^9, 3.7428015790325375`*^9}, {3.742802679030408*^9, 
   3.742802698687467*^9}, {3.7428034596402655`*^9, 3.7428034624528656`*^9}},
 ExpressionUUID -> "485aedf6-77f8-4ae0-8b00-f8406530fe61"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{"exporting", " ", "results"}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"discretizedforw", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"i", ",", 
         RowBox[{"testfunc1sweep", "[", "i", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "0.7", ",", 
         RowBox[{"-", "0.7"}], ",", 
         RowBox[{"-", "0.001"}]}], "}"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"ListLinePlot", "[", "discretizedforw", "]"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"discretizedback", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"i", ",", 
         RowBox[{"testfunc2sweep", "[", "i", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", 
         RowBox[{"-", "0.7"}], ",", "0.7", ",", "0.001"}], "}"}]}], "]"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{"ListLinePlot", "[", "discretizedback", "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{"TotalFit", "=", 
    RowBox[{"Join", "[", 
     RowBox[{"discretizedforw", ",", "discretizedback"}], "]"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{"exportpath", "=", 
    RowBox[{"SystemDialogInput", "[", "\"\<FileOpen\>\"", "]"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{"Export", "[", 
    RowBox[{"exportpath", ",", "TotalFit", ",", "\"\<XLSX\>\""}], "]"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.730450856240938*^9, 3.7304511801057153`*^9}, {
  3.7304512146923866`*^9, 3.7304512152869744`*^9}, {3.730451247965291*^9, 
  3.7304512566721888`*^9}, {3.730451393481262*^9, 3.730451393952015*^9}, {
  3.730451468182376*^9, 3.7304515122614717`*^9}, {3.730451574199171*^9, 
  3.7304515894758015`*^9}, {3.7304519564814253`*^9, 3.7304519787035556`*^9}, {
  3.732716842580303*^9, 3.732716845969979*^9}, {3.732725541723625*^9, 
  3.7327255464811754`*^9}, {3.7428022757745943`*^9, 3.7428022775558844`*^9}, {
  3.742803222396233*^9, 3.7428032232088146`*^9}},
 ExpressionUUID -> "a013a143-1ed5-4607-b349-dd7ef2733076"]
},
EvaluationCompletionAction->"ShowTiming",
WindowSize->{1520, 771},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
Magnification:>1.1 Inherited,
FrontEndVersion->"10.2 for Microsoft Windows (64-bit) (July 29, 2015)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 2160, 60, 313, "Input"],
Cell[2721, 82, 20946, 363, 1160, "Input"],
Cell[23670, 447, 5014, 109, 493, "Input"],
Cell[28687, 558, 29291, 511, 1559, "Input"],
Cell[57981, 1071, 14288, 255, 993, "Input"],
Cell[72272, 1328, 1682, 23, 32, "Input"],
Cell[73957, 1353, 6209, 143, 553, "Input"],
Cell[80169, 1498, 4572, 75, 113, "Input"],
Cell[84744, 1575, 2051, 46, 211, "Input"],
Cell[86798, 1623, 2196, 50, 432, "Input"]
}
]
*)

